*** RUN THIS DOFILE TWICE, THE SECOND TIME COMMENTING OUT LINE 21, THEN RUN REST OF DOFILES***
/***************************************************************************************************************
The Unintended Impacts of an Intimate Partner Violence Prevention Program: Experimental Evidence from Rwanda
REPLICATION FILE 1 - DATA PREPARATION
Prepared by: Ludovic Bequet 10 December 2024
Stata version: 15.1
***************************************************************************************************************/
clear
set more off
cap log close 

***************************************************************
* 1. Treatment variables
***************************************************************

* Load cleaned dataset with baseline and endline data
use "$ROOT/Data/indash_bl_el_clean.dta", clear

* Keep only VSLA couples sample and real couples for endline variable creation
* Drop baseline community couples for treatmemt effect analysis
drop if a12_couples_survey_w_bl==0  // Comment this line and run the dofile a second time (creates the community level dataset)
drop if fake_couple_w_bl==1

***  1.1. Key treatment dummies ***
gen 		couple_type= 0 		if initial_couple_treatment==0 & village_treatment==0	
replace 	couple_type= 1 		if initial_couple_treatment==0 & village_treatment==1
replace 	couple_type= 2 		if initial_couple_treatment==1 & village_treatment==1									
lab def 	couple_type			0 "Pure control" 1 "Spillover couple" 2 "Treated couple"
label val  	couple_type 		couple_type
label var	couple_type			"Treated group of couple"
		
* ITT
rename initial_couple_treatment couple_treat 
label var couple_treat "Treated couple"

* TOT
replace actual_couple_treatment=0 if dropout_m_bl==1 |  fake_couple_m_bl==1

* Spillover couple
gen spillover_couple =0
replace spillover_couple=1 if couple_type==1
label var spillover_couple "Spillover couple"

*** Add distance data 
clonevar couple_id_m_bl = couple_id_bl
merge 1:1 couple_id_m_bl using "$ROOT/Data/distance_to_treatment.dta", nogen
* one outlier:
replace min_distance_to_T=. if min_distance_to_T>30

gen within200=density_T200	
gen within400=density_T200+density_T400	
gen within600=density_T200+density_T400+density_T600
gen within800=density_T200+density_T400+density_T600+density_T800
gen within1000=density_T200+density_T400+density_T600+density_T800+density_T1000


	*** 1.2. Village, strata and training ID ***
	* Village variables
	encode village_id_m_bl, gen (village_id_m_num)
	encode village_res_m, gen (village_res_m_num)
	gen res_village_diff_m=.
	replace res_village_diff_m=village_res_m_num if village_res_m_num!=village_id_m_num & village_res_m_bl!=""

	gen T_village_id=.
	replace T_village_id=village_id_m_num if village_treatment==1

	gen res_village_diff_m_inTreatvil=0
	replace res_village_diff_m_inTreatvil=1 if res_village_diff_m!=. & T_village_id==res_village_diff_m

	encode sector_name_m, gen(sector_id)

	* Location compliance
	gen vill_notres=1 if village_res_w_bl!= village_id_w_bl
	label var vill_notres "Lives in unconfirmed or different village to VSLA-village of treatment assignment"

	* Instrument for spillover compliance
	gen actual_spillover_couple = .
		replace actual_spillover_couple = 0 if village_treatment == 0
		replace actual_spillover_couple = 0 if actual_couple_treatment == 1
		replace actual_spillover_couple = 1 if actual_couple_treatment == 0 & village_treatment == 1
	label var actual_spillover_couple "Spillover couple complier"

	* Create strata to do cross strata
	gen strata=.
	replace strata =1 if sector_id==1 & Napplicantscat==1
	replace strata =2 if sector_id==1 & Napplicantscat==2
	replace strata =3 if sector_id==1 & Napplicantscat==3
	replace strata =4 if sector_id==1 & Napplicantscat==4
	replace strata =5 if sector_id==2 & Napplicantscat==1
	replace strata =6 if sector_id==2 & Napplicantscat==2
	replace strata =7 if sector_id==2 & Napplicantscat==3
	replace strata =8 if sector_id==2 & Napplicantscat==4
	replace strata =9 if sector_id==3 & Napplicantscat==1
	replace strata =10 if sector_id==3 & Napplicantscat==2
	replace strata =11 if sector_id==3 & Napplicantscat==3
	replace strata =12 if sector_id==3 & Napplicantscat==4
	replace strata =13 if sector_id==4 & Napplicantscat==1
	replace strata =14 if sector_id==4 & Napplicantscat==2
	replace strata =15 if sector_id==4 & Napplicantscat==3
	replace strata =16 if sector_id==4 & Napplicantscat==4
	replace strata =17 if sector_id==5 & Napplicantscat==1
	replace strata =18 if sector_id==5 & Napplicantscat==2
	replace strata =19 if sector_id==5 & Napplicantscat==3
	replace strata =20 if sector_id==5 & Napplicantscat==4
	replace strata =21 if sector_id==6 & Napplicantscat==1
	replace strata =22 if sector_id==6 & Napplicantscat==2
	replace strata =23 if sector_id==6 & Napplicantscat==3
	replace strata =24 if sector_id==6 & Napplicantscat==4
	replace strata =25 if sector_id==7 & Napplicantscat==1
	replace strata =26 if sector_id==7 & Napplicantscat==2
	replace strata =27 if sector_id==7 & Napplicantscat==3
	replace strata =28 if sector_id==7 & Napplicantscat==4
	replace strata =29 if sector_id==8 & Napplicantscat==1
	replace strata =30 if sector_id==8 & Napplicantscat==2
	replace strata =31 if sector_id==8 & Napplicantscat==3
	replace strata =32 if sector_id==8 & Napplicantscat==4
	lab var strata "Couples treatment assignment strata: sector and # applicants/VSLA"

	*Cleaning strata variable
	replace strata = 99 if sector_id == 5 & Napplicantscat == 3
	replace strata = 99 if sector_id == 5 & Napplicantscat == 2
	replace strata = 99 if sector_id == 5 & Napplicantscat == 1
	replace strata = 98 if sector_id == 4 & Napplicantscat == 4
	replace strata = 98 if sector_id == 4 & Napplicantscat == 3
	replace strata = 98 if sector_id == 4 & Napplicantscat == 2
	replace strata = 97 if sector_id == 3 & Napplicantscat == 4
	replace strata = 97 if sector_id == 3 & Napplicantscat == 3 
	replace strata = 5 if sector_id == 2 & Napplicantscat == 2
	replace strata = 95 if sector_id == 1 & Napplicantscat == 4
	replace strata = 95 if sector_id == 1 & Napplicantscat == 3
	replace strata = 95 if sector_id == 1 & Napplicantscat == 2

	* Class name cleaning
	replace class_name_m_bl ="Mugesera Class 4" if class_name_m_bl=="Mugesra Class 4"
	gen class_name_m_bl_cl = upper(class_name_m_bl)

	gen training_venue_w_bl_cl = upper(training_venue_w_bl)
	replace training_venue_w_bl_cl="JARAMA CELL OFFICE" if training_venue_w_bl_cl=="IHANIKA BABTIST CHURCH"
	replace training_venue_w_bl_cl="NTAGA CELL OFFICE" if training_venue_w_bl_cl=="NTAGA CELL"
		
	* Delivered trainings
	egen unique_class_asdeliv = group (class_name_m_bl_cl training_venue_w_bl_cl) 
	replace unique_class_asdeliv=. if dropout_w_bl==1
	sort unique_class_asdeliv
	egen tag_delivered = tag(unique_class_asdeliv) 
	egen distinct_delivered = total(tag_delivered) , by(unique_class_asdeliv) 
	bysort unique_class_asdeliv : gen freq_asdeliv = _N  if session_w_bl!=""

	replace distinct_delivered=. if  class_name_m_bl_cl==""
	replace freq_asdeliv=. if  class_name_m_bl_cl==""

	sum distinct_delivered unique_class_asdeliv
	display 626/32 // Average = 19.6 couples / class












***************************************************************
* 2. Baseline variable creation
***************************************************************
rename s22_frcd_degrading_sex_freq_w_bl s22_forced_degrad_sex_freq_w_bl

*** 2.1. IPV variables ***
* Emotional IPV	
gen 		emo_violence_dum_bl=.
replace 	emo_violence_dum_bl=.r 	if  s6_public_humiliation_w_bl==.r | s8_insult_w_bl==.r 
replace 	emo_violence_dum_bl=0 		if s6_public_humiliation_w_bl==0 & s8_insult_w_bl==0
replace 	emo_violence_dum_bl=1 		if s6_public_humiliation_w_bl==1 | s6_public_humiliation_w_bl==2 | s6_public_humiliation_w_bl==3 | /*s7_threat_w==1 | s7_threat_w==2 |s7_threat_w==3 | */ s8_insult_w_bl==1 | s8_insult_w_bl==2 | s8_insult_w_bl==3
tab 		emo_violence_dum_bl, mi
label val  	emo_violence_dum_bl 		yesno

* Physical IPV
gen 		physical_violence_dum_bl=.
replace		physical_violence_dum_bl=.r 	if s9_pushed_freq_w_bl==.r | s10_slapped_freq_w_bl==.r | s11_twisted_arm_freq_w_bl==.r | s12_punched_freq_w_bl==.r | s13_beaten_freq_w_bl==.r | s14_strangled_freq_w_bl==.r | s15_attacked_weapon_freq_w_bl==.r 
replace		physical_violence_dum_bl= 0 	if s9_pushed_freq_w_bl==0 & s10_slapped_freq_w_bl==0 & s11_twisted_arm_freq_w_bl==0 & s12_punched_freq_w_bl==0 & s13_beaten_freq_w_bl==0 & s14_strangled_freq_w_bl==0 & s15_attacked_weapon_freq_w_bl==0 
replace 	physical_violence_dum_bl=1 		if (s9_pushed_freq_w_bl>=1 & s9_pushed_freq_w_bl<=3)  |  (s10_slapped_freq_w_bl>=1 & s10_slapped_freq_w_bl<=3) | (s11_twisted_arm_freq_w_bl>=1 & s11_twisted_arm_freq_w_bl<=3)  | (s12_punched_freq_w_bl>=1 & s12_punched_freq_w_bl<=3) | (s13_beaten_freq_w_bl>=1 & s13_beaten_freq_w_bl<=3) | (s14_strangled_freq_w_bl>=1 & s14_strangled_freq_w_bl<=3) | (s15_attacked_weapon_freq_w_bl>=1 & s15_attacked_weapon_freq_w_bl <=3) 
label val  	physical_violence_dum_bl 		yesno
label var	physical_violence_dum_bl		"Baseline Experienced at least 1 form of physical violence in last 12m"

* Sexual IPV
gen 		sexual_violence_dum_bl=.
replace 	sexual_violence_dum_bl=.r 		if s20_forced_sex_phys_freq_w_bl==.r | s21_forced_sex_fear_freq_w_bl==.r | s22_forced_degrad_sex_freq_w_bl==.r
replace  	sexual_violence_dum_bl= 0 		if s20_forced_sex_phys_freq_w_bl==0 & s21_forced_sex_fear_freq_w_bl==0 & s22_forced_degrad_sex_freq_w_bl==0
replace	 	sexual_violence_dum_bl=1 		if (s20_forced_sex_phys_freq_w_bl>=1 & s20_forced_sex_phys_freq_w_bl<=3) | (s21_forced_sex_fear_freq_w_bl>=1 & s21_forced_sex_fear_freq_w_bl<=3) | (s22_forced_degrad_sex_freq_w_bl>=1 & s22_forced_degrad_sex_freq_w_bl<=3)
label val  	sexual_violence_dum_bl 			yesno
label var	sexual_violence_dum_bl			"Baseline Experienced at least 1 form of sexual violence in last 12m"

* Physical OR sexual violence
gen 		phys_or_sex_vio_bl=0
replace 	phys_or_sex_vio_bl=1 			if physical_violence_dum_bl==1 | sexual_violence_dum_bl==1
label val  	phys_or_sex_vio_bl 				yesno
label var	phys_or_sex_vio_bl				"Baseline Experienced at least 1 form of physical and/or sexual violence in last 12m"

* Any form of violence: Emotional, physical or sexual
gen 		any_vio_bl=0
replace 	any_vio_bl=.r 					if physical_violence_dum_bl==.r | sexual_violence_dum_bl==.r | emo_violence_dum_bl==.r 
replace 	any_vio_bl=1 					if physical_violence_dum_bl==1 | sexual_violence_dum_bl==1 | emo_violence_dum_bl==1 
label val  	any_vio_bl 						yesno
label var	any_vio_bl						"Experienced any emotional, physical or sexual violence in last 12m"	 
		
gen 		no_vio_bl = 1 if 				any_vio_bl == 0
replace		no_vio_bl = 0 if 				any_vio_bl == 1
replace 	no_vio_bl = .r if 				any_vio_bl == .r
label var 	no_vio_bl						"Did not experience any violence in last 12m"

* Refusal rates:
rename s15_attacked_weapon_freq_w_bl s15_attck_weapn_freq_w_bl 
rename s20_forced_sex_phys_freq_w_bl s20_frc_sex_freq_w_bl 
rename s21_forced_sex_fear_freq_w_bl s21_frc_sex_fear_freq_w_bl 
rename s22_forced_degrad_sex_freq_w_bl s22_degrd_sex_freq_w_bl 
				
local ipv_outcomes s6_public_humiliation_w_bl s7_threat_w_bl s8_insult_w_bl s9_pushed_freq_w_bl s10_slapped_freq_w_bl s11_twisted_arm_freq_w_bl s12_punched_freq_w_bl s13_beaten_freq_w_bl s14_strangled_freq_w_bl  s15_attck_weapn_freq_w_bl  s20_frc_sex_freq_w_bl s21_frc_sex_fear_freq_w_bl s22_degrd_sex_freq_w_bl
foreach x of varlist `ipv_outcomes'  {
	gen ref_`x' 	= 0 if (`x'!=.)
	replace ref_`x' =1 	if `x'==.r
	label var ref_`x' "Refused to answer `x'"
}

gen emo_vio_ref_bl= 0
replace emo_vio_ref_bl= 1 if ref_s6_public_humiliation_w_bl==1 | ref_s8_insult_w_bl==1  
	
gen phys_vio_ref_bl= 0
replace phys_vio_ref_bl= 1 if ref_s10_slapped_freq_w_bl==1| ref_s11_twisted_arm_freq_w_bl==1| ref_s12_punched_freq_w_bl==1| ref_s13_beaten_freq_w_bl==1| ref_s14_strangled_freq_w_bl==1| ref_s15_attck_weapn_freq_w_bl==1
	
gen sex_vio_ref_bl= 0
replace sex_vio_ref_bl= 1 if ref_s20_frc_sex_freq_w_bl==1 |ref_s21_frc_sex_fear_freq_w_bl==1| ref_s22_degrd_sex_freq_w_bl==1
	
* Controlling behaviours 							
gen 		emo_contrl_behav_dum_bl=.
replace 	emo_contrl_behav_dum_bl=.r 	if s1_jealousy_w_bl==.r | s2_unfaithful_accuse_w_bl==.r | s3_prevent_friends_w_bl==.r | s4_limit_family_contact_w_bl==.r | s5_always_know_location_w_bl==.r 
replace 	emo_contrl_behav_dum_bl=0 		if s1_jealousy_w_bl==0 & s2_unfaithful_accuse_w_bl==0 & s3_prevent_friends_w_bl==0 & s4_limit_family_contact_w_bl==0 & s5_always_know_location_w_bl==0 
replace 	emo_contrl_behav_dum_bl=1 		if s1_jealousy_w_bl==1 | s2_unfaithful_accuse_w_bl==1 | s3_prevent_friends_w_bl==1 | s4_limit_family_contact_w_bl==1 | s5_always_know_location_w_bl==1 
tab 		emo_contrl_behav_dum_bl, mi
label val  	emo_contrl_behav_dum_bl 		yesno
label var	emo_contrl_behav_dum_bl		"Experienced at least 1 form of controlling behaviours in last 12m"

* Number of violence
global emo_vio "s6_public_humiliation_w_bl  s8_insult_w_bl"	
global phys_vio " s10_slapped_freq_w_bl s11_twisted_arm_freq_w_bl s12_punched_freq_w_bl s13_beaten_freq_w_bl s14_strangled_freq_w_bl s15_attck_weapn_freq_w_bl "	/* s15_attacked_weapon_freq_w*/
global sexual_vio "s20_frc_sex_freq_w_bl s21_frc_sex_fear_freq_w_bl s22_degrd_sex_freq_w_bl" 

foreach x of varlist $emo_vio $phys_vio $sexual_vio {
	gen 	d_`x'=. 	if (`x'==.)
	replace d_`x'=.r 	if (`x'==.r)
	replace d_`x'=0 	if `x'==0
	replace d_`x'=1 	if `x'==1 | `x'==2 | `x'==3 
}

egen 	emo_vio_numb_bl= 	rowtotal	(d_s6_public_humiliation_w_bl d_s8_insult_w_bl )
replace emo_vio_numb_bl=. 	if 	emo_violence_dum_bl==.

egen 	phys_vio_numb_bl= 	rowtotal	(d_s10_slapped_freq_w_bl d_s11_twisted_arm_freq_w_bl d_s12_punched_freq_w_bl d_s13_beaten_freq_w_bl d_s14_strangled_freq_w_bl d_s15_attck_weapn_freq_w_bl)
replace phys_vio_numb_bl=. if 	physical_violence_dum_bl==.

egen 	sex_vio_numb_bl= 	rowtotal	(d_s20_frc_sex_freq_w_bl d_s21_frc_sex_fear_freq_w_bl d_s22_degrd_sex_freq_w_bl)
replace sex_vio_numb_bl=. 	if 	sexual_violence_dum_bl==.
	
* Violence against men dummy
gen 	physical_violence_m_bl=.
replace physical_violence_m_bl= 0 		if u2_ptnr_violent_freq_m_bl==0
replace physical_violence_m_bl= 1 		if (u2_ptnr_violent_freq_m_bl>=1 & u2_ptnr_violent_freq_m_bl<=3)

gen 	emo_violence_m_bl=.
replace emo_violence_m_bl= 0 	if u4_ptnr_emot_abused_freq_m_bl==0
replace emo_violence_m_bl= 1 	if (u4_ptnr_emot_abused_freq_m_bl>=1 & u4_ptnr_emot_abused_freq_m_bl<=3)

* IPV frequency
clonevar slapped_freq_w_bl = d_s10_slapped_freq_w_bl
clonevar twisted_arm_freq_w_bl = d_s11_twisted_arm_freq_w_bl
clonevar punched_freq_w_bl = d_s12_punched_freq_w_bl  
clonevar beaten_freq_w_bl = d_s13_beaten_freq_w_bl
clonevar strangled_freq_w_bl = d_s14_strangled_freq_w_bl 
clonevar attacked_wpn_freq_w_bl = s15_attck_weapn_freq_w_bl
clonevar forced_sex_freq_w_bl = s20_frc_sex_freq_w_bl 
clonevar forced_sex_fear_freq_w_bl = s21_frc_sex_fear_freq_w_bl 
clonevar degrd_sex_freq_w_bl = s22_degrd_sex_freq_w_bl

local vio_freq slapped_freq_w_bl twisted_arm_freq_w_bl punched_freq_w_bl beaten_freq_w_bl strangled_freq_w_bl attacked_wpn_freq_w_bl forced_sex_freq_w_bl forced_sex_fear_freq_w_bl degrd_sex_freq_w_bl
foreach x of varlist `vio_freq' {
	tab `x',mi
	gen `x'_sof = .
	replace `x'_sof=1 if `x' ==2 | `x'==3
	replace `x'_sof=0 if `x'==0 | `x'==1
	replace `x'_sof=.r if `x'==.r
	label var `x'_sof "Sometimes or often experienced `x'"
}
rename *freq_w_bl_sof *w_sof_bl

* BL Extra robustness variable: code all refuse as yes
gen emo_vio_act_refeqlyes_bl= emo_violence_dum_bl
replace emo_vio_act_refeqlyes_bl= 1 if ref_s6_public_humiliation_w_bl==1 | ref_s8_insult_w_bl==1  
label var	emo_vio_act_refeqlyes_bl		"BL Emotional vio: all refuses coded as yes "

gen phys_vio_refeqlyes_bl= physical_violence_dum_bl
replace phys_vio_refeqlyes_bl= 1 if ref_s10_slapped_freq_w_bl==1| ref_s11_twisted_arm_freq_w_bl==1| ref_s12_punched_freq_w_bl==1| ref_s13_beaten_freq_w_bl==1| ref_s14_strangled_freq_w_bl==1|  ref_s15_attck_weapn_freq_w_bl==1
label var	phys_vio_refeqlyes_bl		"BL Physical vio: all refuses coded as yes "	

gen sex_vio_act_refeqlyes_bl= sexual_violence_dum_bl
replace sex_vio_act_refeqlyes_bl= 1 if ref_s20_frc_sex_freq_w_bl==1 |ref_s21_frc_sex_fear_freq_w_bl==1| ref_s22_degrd_sex_freq_w_bl==1
label var	sex_vio_act_refeqlyes_bl		"BL Sexual vio: all refuses coded as yes "		

* BL Extra robustness variable: code all refuse as no
gen emo_vio_act_refeqlno_bl= emo_violence_dum_bl
replace emo_vio_act_refeqlno_bl= 0 if ref_s6_public_humiliation_w_bl==1 | ref_s8_insult_w_bl==1  
label var	emo_vio_act_refeqlno_bl		"BL Emotional vio: all refuses coded as no "

gen phys_vio_refeqlno_bl= physical_violence_dum_bl
replace phys_vio_refeqlno_bl= 0 if ref_s10_slapped_freq_w_bl==1| ref_s11_twisted_arm_freq_w_bl==1| ref_s12_punched_freq_w_bl==1| ref_s13_beaten_freq_w_bl==1| ref_s14_strangled_freq_w_bl==1|  ref_s15_attck_weapn_freq_w_bl==1
label var	phys_vio_refeqlno_bl		"BL Physical vio: all refuses coded as no "	

gen sex_vio_act_refeqlno_bl= sexual_violence_dum_bl
replace sex_vio_act_refeqlno_bl= 0 if ref_s20_frc_sex_freq_w_bl==1 |ref_s21_frc_sex_fear_freq_w_bl==1| ref_s22_degrd_sex_freq_w_bl==1
label var	sex_vio_act_refeqlno_bl		"BL Sexual vio: all refuses coded as no "		

* Rename some variables to shorter names
rename s17_injury_mnr_4m_violence_w_bl 	s17_injuries_minor_bl 
rename s23_injury_4m_forced_sex_w_bl 	s23_injuries_sex_w_bl 
rename d_s6_public_humiliation_w_bl 	public_humiliation_w_bl 
rename d_s8_insult_w_bl 				insult_w_bl
rename d_s10_slapped_freq_w_bl 			slapped_w_bl
rename d_s11_twisted_arm_freq_w_bl 		twisted_arm_w_bl
rename d_s12_punched_freq_w_bl 			punched_w_bl  
rename d_s13_beaten_freq_w_bl 			beaten_w_bl
rename d_s14_strangled_freq_w_bl 		strangled_w_bl 
rename d_s15_attck_weapn_freq_w_bl 		attacked_wpn_w_bl
rename d_s20_frc_sex_freq_w_bl  		forced_sex_w_bl
rename d_s21_frc_sex_fear_freq_w_bl 	forced_sex_fear_w_bl 
rename d_s22_degrd_sex_freq_w_bl 		degrd_sex_w_bl
rename oo1_meta2_signs_phys_pain_w_bl 	oo1_m2_signphyspain_w_bl
rename oo5_meta5_counsel_referral_w_bl 	oo5_m5_cnsl_refer_w_bl
rename oo6_meta6_spoke_counsel_w_bl 	oo6_m6_spk_cnsl_w_bl

	*** 2.2. Men-only variables ***
	  
	* IPV justifed? How many time IPV is justified out of 5 scenarios. More is worse.
	gen 	own_ipv_justified_m_bl = q1_beating_neglect_children_m_bl + q2_beating_refusing_sex_m_bl + q3_beating_disobey_m_bl + q4_beating_burn_food_m_bl + q5_beating_suspect_cheating_m_bl
	label 	var		own_ipv_justified_m_bl		"Number of reasons husband thinks IPV is justified"
			
	* Refusing sex justified? More is better.
	gen own_refusesex_m_bl = r1_refuse_know_unfaithful_m_bl+ r2_refuse_drunk_m_bl + r3_refuse_mistreatment_m_bl + r4_refuse_condoms_m_bl 
	label 	var		own_refusesex_m_bl		"Number of reasons husband thinks a wife refusing sex is justified"
		
	* Men's intention to commit violence. More is worse.
	gen intent_violence_m_bl= s1_disrespect_m_bl + s2_threat_leaving_m_bl + s3_cheating_m_bl + s4_flirting_m_bl + s5_spend_money_m_bl + s6_mock_m_bl +s7_control_m_bl +s8_interrupt_m_bl +s9_impt_decision_m_bl +s10_leaving_m_bl   
	label 	var		intent_violence_m_bl		"Sum of likert scales: Situations respondent would be likely to becoming violent"

	* Men would become intimidating. More is worse.
	gen 	become_intimidating_m_bl=t1_intim_disrespect_m_bl + t2_intim_threat_leaving_m_bl+ t3_intim_flirting_m_bl + t4_intim_ridicule_m_bl + t5_intim_impt_decision_m_bl
	label 	var		become_intimidating_m_bl		"Sum of likert scales: Situations respondent would be likely to becoming intimidating"

	* Parental IPV
	gen aa12_fth_phipv_m_bl_dm=.
	replace  aa12_fth_phipv_m_bl_dm=0 if aa12_father_beating_m_bl==4
	replace  aa12_fth_phipv_m_bl_dm=1 if aa12_father_beating_m_bl==1 | aa12_father_beating_m_bl==2 | aa12_father_beating_m_bl==3

	* Total number of trauma incidents 
	gen trauma_score_m_bl= aa1_flee_house_m_bl+ aa2_relatives_lost_m_bl +aa3_injured_m_bl +aa4_murder_witness_m_bl +aa5_rape_witness_m_bl +aa6_job_loss_m_bl +aa7_adult_sickness_m_bl +aa8_assets_lost_m_bl
	label 	var		trauma_score_m_bl		"Number of traumatic experiences the husband has faced"

	* Number of depression symptoms  - men 
	local depression_m_bl "cc1_pleasure_m_bl cc2_down_m_bl cc3_sleep_m_bl cc4_energy_m_bl cc5_appetite_m_bl cc6_failure_m_bl cc7_concentrate_m_bl cc8_movement_dep_m_bl cc9_hurt_self_m_bl"

	foreach var of varlist `depression_m_bl' {	
		gen dep_`var'=`var'-1
	}

	* Depression severity
	gen dep_total_score_m_bl= dep_cc1+ dep_cc2 + dep_cc3 + dep_cc4 + dep_cc5 + dep_cc6 + dep_cc7 + dep_cc8 + dep_cc9 
	replace dep_total_score_m_bl=. if dep_total_score<0
	label 	var		dep_total_score_m_bl		"Total depression score"
	tab dep_total_score_m_bl, mi

	* Own Gender Equitable Norms-  NOTE: Higher score = more gender INEQUITABLE. 0 = more gender equitable
	gen own_gendernorms_m_bl=.
	replace own_gendernorms_m_bl= k5_shame_husband_hhwork_m_bl +  k6_obey_husband_m_bl + k7_woman_control_man_m_bl + k8_ipv_private_m_bl
	label 	var		own_gendernorms_m_bl		"Number of gender inequitable attitudes respondent expresses"
	tab own_gendernorms_m_bl,mi

	* Beliefs on IPV prevalence in the community
	gen cmty_beat_wife_low_bl = dd7_cmty_beat_wife_m_bl <= 2	
		replace cmty_beat_wife_low_bl = . if dd7_cmty_beat_wife_m_bl == .
	label var cmty_beat_wife_low_bl "At most 25\% of men beat up wife"
	gen cmty_force_sex_low_bl = dd8_cmty_force_sex_m_bl <= 2	
		replace cmty_force_sex_low_bl = . if dd8_cmty_force_sex_m_bl == .
	label var cmty_force_sex_low_bl "At most 25\% of men force wife to have sex"



		*** 2.3.  Women-only variables ***

		* Marriage status
		gen 		civil_legal_marriage_bl =0
		replace 	civil_legal_marriage_bl=1 if  d11_marriage_type_2_w_bl==1
		label 	var	civil_legal_marriage_bl		"Civil or legal marriage"
		label	val	civil_legal_marriage_bl 	yesno

		* Married at BL- exogenous
		gen married_w_bl= d11_marriage_type_2_w_bl==1
		lab var married_w_bl "Married at baseline"

		* Own Gender Equitable Norms-  NOTE: Higher score= more gender INEQUITABLE. 0 = more gender equitable
		gen own_gendernorms_w_bl=.
		replace own_gendernorms_w_bl= l1_shame_husband_hhwork_w_bl +  l2_obey_husband_w_bl + l3_woman_control_man_w_bl + l4_ipv_private_w_bl
		label 	var		own_gendernorms_w_bl		"Number of gender inequitable attitudes respondent expresses"

		* IPV justifed? how many time is ipv justified out of 5? More is worse.
		gen own_ipv_justified_w_bl = q1_beating_neglect_children_w_bl + q2_beating_refusing_sex_w_bl + q3_beating_disobey_w_bl + q4_beating_burn_food_w_bl + q5_beating_suspect_cheating_w_bl
		label 	var		own_ipv_justified_w_bl		"Number of situations wife thinks IPV is justified"
				
		* Refusing sex justified? More is better
		gen own_refusesex_w_bl = r1_refuse_know_unfaithful_w_bl+ r2_refuse_drunk_w_bl + r3_refuse_mistreatment_w_bl + r4_refuse_condoms_w_bl 
		label 	var		own_refusesex_w_bl		"Number of situations wife thinks refusing sex is justified"
			
		* Women's decision-making:
		foreach x of varlist k4_comm__maj_purch2_w_bl k6_comm_edu2_w_bl k2_comm_money2_w_bl {
			gen `x'_men =0 if `x'==1 | `x'==3 | `x'==4
			replace `x'_men=1 if `x'==2
		} 
			
		 * Women input
		rename k2_comm_money2_w_bl dec_input_hh_inc_w_bl
		rename k4_comm__maj_purch2_w_bl dec_input_hh_exp_w_bl
		rename k6_comm_edu2_w_bl dec_input_eduexp_w_bl

		global decision_input_w_bl "dec_input_hh_inc_w_bl dec_input_hh_exp_w_bl dec_input_eduexp_w_bl "
		foreach var of varlist  $decision_input_w_bl   {
			gen `var'_role=.
			replace `var'_role=0 if /*`var'==-97 |*/ `var'==2 | `var'==4
			replace `var'_role=1 if (`var'==1 | `var'==3)
			label var `var'_role  "BL Wife has input in decision_`var'"
		} 

		gen lottery = pid_w_bl
		label var lottery "Baseline lottery rank (1-20)"



			*** 2.4. Men and women

			* Different effects if got married before the genocide vs after when different marriage market?  
			gen gap_agenow_agemarr=(d8_age_years_w_bl-d10_age_at_marriage_w_bl)

			* Narrow bands to avoid strong age effects
			gen married_pre94_narr=0 if gap_agenow_agemarr>15 & gap_agenow_agemarr<24
			replace married_pre94_narr=1 if gap_agenow_agemarr>25  & gap_agenow_agemarr<35


			* Education 
			// Recode education to mean zero years schooling is 0
			gen e29_education_m_bl_clean=e29_education_m_bl-1
			gen e11_education_w_bl_clean=e11_education_w_bl-1
			// Make vocational educ = 1st year of uni
			replace e29_education_m_bl_clean=13 if e29_education_m_bl==19
			replace e11_education_w_bl_clean=13 if e11_education_w_bl==19
						
			* Networks
			gen 		numb_closefriends_m_bl=gg1_friend_num_m_bl + rg1_n_m_bl
			replace 	numb_closefriends_m_bl=0 if numb_closefriends_m_bl==.
			label 		var		numb_closefriends_m_bl		"Total number of close friends husband reports"

			gen 		numb_villagerels_m_bl=gg4_relative_blood_num_m_bl+ rg2_num_m_bl
			replace 	numb_villagerels_m_bl=0 if numb_villagerels_m_bl==.
			label 		var		numb_villagerels_m_bl		"Total number of blood relatives husband reports"


			gen 		numb_closefriends_w_bl=bb1_friend_num_w_bl + rg1_n_w
			replace 	numb_closefriends_w_bl=0 if numb_closefriends_w_bl==.
			label 		var		numb_closefriends_w_bl		"Total number of close friends wife reports"

			gen 		numb_villagerels_w_bl=bb1_relative_blood_num_w_bl+ rg2_num_w_bl
			replace 	numb_villagerels_w_bl=0 if numb_villagerels_w_bl==.
			label 		var		numb_villagerels_w_bl		"Total number of blood relatives wife reports"
				


				*** 2.5. Norms Vignette Analysis ***

				* 2.5.1. Women *
				* Gender equal norms vignette:
				// Is beating wife in village  socially appropriate? Leave 1 as very inappropriate, 4 is very appropriate
				gen norms_q1_w_bl=.
				replace norms_q1_w_bl=mm6_sit6_module3_situation1
				label var norms_q1_w_bl "Wife beating socially appropriate"

				// Is leaving your violent husband socially appropriate? Make 1 very appropriate
				gen norms_q2_w_bl=.
				replace norms_q2_w_bl=1 if mm7_sit7_module3_situation2==4
				replace norms_q2_w_bl=2 if mm7_sit7_module3_situation2==3
				replace norms_q2_w_bl=3 if mm7_sit7_module3_situation2==2
				replace norms_q2_w_bl=4 if mm7_sit7_module3_situation2==1
				label var norms_q2_w_bl "Leaving violent husband not socially appropriate"

				// Is asking a woman to go back to her violent husband socially appropriate? Leave 1=very socially inappropriate, and 4= very appropriate
				gen norms_q3_w_bl=.
				replace norms_q3_w_bl= mm8_sit8_module3_situation3
				label var norms_q3_w_bl "Asking a woman to go back to violent husband socially approporiate"

				// Is reporting your violent husband to the police appropriate. Make 1 very appropriate 
				gen norms_q4_w_bl=.
				replace norms_q4_w_bl=1 if mm9_sit9_module3_situation4==4
				replace norms_q4_w_bl=2 if mm9_sit9_module3_situation4==3
				replace norms_q4_w_bl=3 if mm9_sit9_module3_situation4==2
				replace norms_q4_w_bl=4 if mm9_sit9_module3_situation4==1
				label var norms_q4_w_bl "Reporting IPV to police not socially approporiate"


				* 2.5.2. Men *
				/* --> Lower score means more gender equal norms. High score --> more gender inequitable
				Each response to the norms vignettes is given a score from 1-4. 1 is 
				perception that village is most gender equal, and score of 4 is perception 
				that village is most gender UNEQUAL.--> Bigger is worse */

				* Gender equal norms vignette:
				// Is beating wife in village  socially appropriate? Leave 1 as very inappropriate, 4 is very appropriate
				gen norms_q1_m_bl=.
				replace norms_q1_m_bl=pp6_sit6_module3_situation1
				label var norms_q1_m_bl "Wife beating socially appropriate"

				// Is leaving your violent husband socially appropriate? Make 1 very appropriate
				gen norms_q2_m_bl=.
				replace norms_q2_m_bl=1 if pp7_sit7_module3_situation2==4
				replace norms_q2_m_bl=2 if pp7_sit7_module3_situation2==3
				replace norms_q2_m_bl=3 if pp7_sit7_module3_situation2==2
				replace norms_q2_m_bl=4 if pp7_sit7_module3_situation2==1
				label var norms_q2_m_bl "Leaving violent husband not socially appropriate"

				// Is asking a woman to go back to her violent husband socially appropriate? Leave 1=very socially inappropriate, and 4= very appropriate
				gen norms_q3_m_bl=.
				replace norms_q3_m_bl= pp8_sit8_module3_situation3
				label var norms_q3_m_bl "Asking a woman to go back to violent husband socially approporiate"

				// Is reporting your violent husband to the police appropriate. Make 1 very appropriate 
				gen norms_q4_m_bl=.
				replace norms_q4_m_bl=1 if pp9_sit9_module3_situation4==4
				replace norms_q4_m_bl=2 if pp9_sit9_module3_situation4==3
				replace norms_q4_m_bl=3 if pp9_sit9_module3_situation4==2
				replace norms_q4_m_bl=4 if pp9_sit9_module3_situation4==1
				label var norms_q4_m_bl "Reporting IPV to police not socially approporiate"



					*** 2.6. Relationship quality and attitudes

					* Generate a trust measure that increases with trust:
					* Create positive variables - invert so more is better
					foreach var of varlist  m3_partner_trust2_w_bl  l3_partner_trust2_m_bl  {
					gen `var'_p=.
					replace `var'_p=0 if `var'==4
					replace `var'_p=1 if `var'==3
					replace `var'_p=2 if `var'==2
					replace `var'_p=3 if `var'==1
					label var `var'_p  "Postv_`var'"
					}	

					label def trust_inv  0 "In no matters" 1 "In some matters" 2 "In most matters" 3 "In all matters"
					label val  m3_partner_trust2_w_bl_p trust_inv
					label val  l3_partner_trust2_m_bl_p trust_inv


					* Changing long var names for interactin terms use in list analysis
					clonevar dd1_cmty_shame_hhwrk_m_bl 	=	dd1_cmty_shame_hsbnd_hhwrk_m_bl
					clonevar dd2_cmty_obey_husb_m_bl 	=	dd2_cmty_obey_husband_m_bl
					clonevar dd7_cmty_btwife_m_bl	 	=	dd7_cmty_beat_wife_m_bl
					rename t1_partner_alcohol_use_w_bl 		t1_ptnr_alcl_use_w_bl
					rename h23_savings_amount_w_bl 			h23_savings_amt_w_bl
					rename q1_beating_neglect_children_w_bl	q1_beat_neglect_child_w_bl
					rename q5_beating_suspect_cheating_w_bl	q5_beat_suspect_unfaith_w_bl
					rename l1_shame_husband_hhwork_w_bl		l1_shame_hhwork_w_bl
					rename dd3_cmty_woman_control_man_m_bl 	dd3_cmty_womcontl_m_bl
					rename dd4_cmty_no_intervene_ipv_m_bl 	dd4_cmty_nointv_ipv_m_bl
					rename dd6_cmty_prohibit_visits_m_bl 	dd6_cmty_prohib_vist_m_bl
					rename t2_partner_drinks_too_much_w_bl 	t2_ptnr_drinktoomuch_w_bl
					rename t2_intim_threat_leaving_m_bl 	t2_intim_thrtleav_m_bl
					rename gg8_relationship_talks_num_m_bl 	gg8_rel_talks_num_m_bl
					rename gg4_relative_blood_num_m_bl 	gg4_rel_blood_num_m_bl

					global bl_norms_m "dd1_cmty_shame_hhwrk_m_bl dd2_cmty_obey_husb_m_bl dd3_cmty_womcontl_m_bl dd4_cmty_nointv_ipv_m_bl  dd6_cmty_prohib_vist_m_bl dd7_cmty_btwife_m_bl dd8_cmty_force_sex_m_bl " /* dd5_cmty_jlsy_m_bl*/
					global bl_norms_w  "z1_cmty_shame_hsbnd_hhwrk_w_bl z2_cmty_obey_husband_w_bl z3_cmty_woman_control_man_w_bl z4_cmty_no_intervene_ipv_w_bl z5_cmnty_jealousy_w_bl z6_cmty_beat_wife_w_bl z7_cmty_force_sex_w_bl"

					 foreach x of varlist $bl_norms_m {
						local newvar = substr("`x'", 1, 13)
						gen `newvar'_m_bl = `x' 
					 }
					 
					 foreach x of varlist $bl_norms_w {
						local newvar = substr("`x'", 1, 13)
						gen `newvar'_w_bl = `x' 
					 }

					* Likelihood of men becoming violent: 
					global men_beat_likely_bl 		"s1_disrespect_m_bl s2_threat_leaving_m_bl s3_cheating_m_bl s4_flirting_m_bl s5_spend_money_m_bl s6_mock_m_bl s7_control_m_bl s8_interrupt_m_bl s9_impt_decision_m_bl s10_leaving_m_bl"
					global men_likely_intimid_bl 	"t1_intim_disrespect_m_bl t2_intim_thrtleav_m_bl t3_intim_flirting_m_bl t4_intim_ridicule_m_bl t5_intim_impt_decision_m_bl"

					* Men's intention to commit violence: higher score= worse 
					foreach x of varlist $men_beat_likely_bl $men_likely_intimid_bl {
						gen 		`x'_lkly=.
						replace  	`x'_lkly=0  	if (`x'==1 | `x'==2)
						replace  	`x'_lkly=1  	if (`x'==3 | `x'==4)
						label var `x'_lkly "BL Dummy men likely violent -`x'"
					}

					* Men's become intimidating: higher score= worse 
					egen reasons_lklyvio_m_eg_bl = rowtotal (s1_disrespect_m_bl_lkly s2_threat_leaving_m_bl_lkly s3_cheating_m_bl_lkly s4_flirting_m_bl_lkly s5_spend_money_m_bl_lkly s6_mock_m_bl_lkly s7_control_m_bl_lkly s8_interrupt_m_bl_lkly s9_impt_decision_m_bl_lkly s10_leaving_m_bl_lkly t1_intim_disrespect_m_bl_lkly  t2_intim_thrtleav_m_bl_lkly t3_intim_flirting_m_bl_lkly t4_intim_ridicule_m_bl_lkly t5_intim_impt_decision_m_bl_lkly)
					replace reasons_lklyvio_m_eg_bl=. if s1_disrespect_m_bl_lkly==. & s2_threat_leaving_m_bl_lkly==. & s3_cheating_m_bl_lkly==. & s4_flirting_m_bl_lkly==. & s5_spend_money_m_bl_lkly==. & s6_mock_m_bl_lkly==. & s7_control_m_bl_lkly==. & s8_interrupt_m_bl_lkly==. & s9_impt_decision_m_bl_lkly==. & s10_leaving_m_bl_lkly==. & t1_intim_disrespect_m_bl_lkly==. & t2_intim_thrtleav_m_bl==. & t3_intim_flirting_m_bl_lkly==. & t4_intim_ridicule_m_bl_lkly==. & t5_intim_impt_decision_m_bl_lkly==. 
					label 	var		reasons_lklyvio_m_eg_bl	"BL Number of hypothetical situations men would be likley to become violent- out of 15"
					drop *_m_bl_lkly

					* Incentivized:  more is worse
					local incentivized_bl norms_q1_w_bl norms_q2_w_bl norms_q3_w_bl norms_q4_w_bl norms_q1_m_bl norms_q2_m_bl norms_q3_m_bl norms_q4_m_bl
					foreach x of varlist `incentivized_bl' {
						gen ineq_`x'=.
						replace ineq_`x'=1 if `x'==3 | `x'==4
						replace ineq_`x'=0 if `x'==1 | `x'==2
					}

					* Incentivized:  more is worse
					local incentivized_bl norms_q1_w_bl norms_q2_w_bl norms_q3_w_bl norms_q4_w_bl norms_q1_m_bl norms_q2_m_bl norms_q3_m_bl norms_q4_m_bl
					foreach x of varlist `incentivized_bl' {
						*reg 	`x'				couple_treat spillover_couple   i.strata ,  vce(cluster village_id_m_bl)
						gen ineqindx`x'=.
						replace ineqindx`x'=1 if `x'==3 
						replace ineqindx`x'=2 if `x'==4
						replace ineqindx`x'=0 if `x'==1 | `x'==2
					}

					* IPV attitudes
					rename q1_beating_neglect_children_m_bl q1_beat_negl_child_m_bl
					rename q5_beating_suspect_cheating_m_bl q5_beat_susp_cheat_m_bl
					foreach var of varlist q1_beat_neglect_child_w_bl  q2_beating_refusing_sex_w_bl  q3_beating_disobey_w_bl  q4_beating_burn_food_w_bl  q5_beat_suspect_unfaith_w_bl q1_beat_negl_child_m_bl  q2_beating_refusing_sex_m_bl  q3_beating_disobey_m_bl  q4_beating_burn_food_m_bl  q5_beat_susp_cheat_m_bl {
						gen `var'_p=0
						replace `var'_p=1 if `var'==0
						replace `var'_p=0 if `var'==1
					} 
					gen own_ipv_justified_w_equit_bl= q1_beat_neglect_child_w_bl_p + q2_beating_refusing_sex_w_bl_p + q3_beating_disobey_w_bl_p + q4_beating_burn_food_w_bl_p + q5_beat_suspect_unfaith_w_bl_p	
					gen own_ipv_justified_m_equit_bl= q1_beat_negl_child_m_bl_p+ q2_beating_refusing_sex_m_bl_p+ q3_beating_disobey_m_bl_p+ q4_beating_burn_food_m_bl_p + q5_beat_susp_cheat_m_bl_p

					* Baseline friction variables		
					foreach var of varlist  l1_shame_hhwork_w_bl   l2_obey_husband_w_bl  l3_woman_control_man_w_bl  l4_ipv_private_w_bl k5_shame_husband_hhwork_m_bl   k6_obey_husband_m_bl   k8_ipv_private_m_bl /* k7_woman_control_man_m_bl*/{
									gen `var'_p=0
									replace `var'_p=1 if `var'==0
									replace `var'_p=0 if `var'==1
								} 
					gen own_gendernorms_m_equit_bl= k5_shame_husband_hhwork_m_bl_p+ k6_obey_husband_m_bl_p+ k8_ipv_private_m_bl_p
					gen own_gendernorms_w_equit_bl= l1_shame_hhwork_w_bl_p + l2_obey_husband_w_bl_p +/* l3_woman_control_man_w_bl_p +*/ l4_ipv_private_w_bl_p 

					gen gap_gndrnrms_bl= (own_gendernorms_w_equit_bl-own_gendernorms_m_equit_bl)
					label 	var	gap_gndrnrms_bl		"Attitude Gap wife fewer gender inequitable atts than husb"

					gen gap_ipvjust_bl= (own_ipv_justified_w_equit_bl -own_ipv_justified_m_equit_bl)
					label 	var	gap_ipvjust_bl		"Attitude Gap wife fewer ipv acceptability atts than husb"

					* Additional variables
					gen unable_to_work_w_bl=0
					replace unable_to_work_w_bl=1 if h6_reason_not_working2_w_bl==2

					gen v2_alcohol_excess_dum_m_bl = 0
					replace v2_alcohol_excess_dum_m_bl=1 if v2_alcohol_excess_m_bl==1 | v2_alcohol_excess_m_bl==2 | v2_alcohol_excess_m_bl==3

					gen knew_gendertraining_w_bl = .
					replace knew_gendertraining_w_bl=0 if aa1_training_topic_w_bl==1 | aa1_training_topic_w_bl==2 | aa1_training_topic_w_bl==4
					replace knew_gendertraining_w_bl=1 if aa1_training_topic_w_bl==3
					label var knew_gendertraining_w_bl "Knew training was about families and gender equality"

					* Village mean gender norms
						bysort village_id_w: egen vmn_own_gendernorms_w_bl = mean (own_gendernorms_w_bl) 
						label var vmn_own_gendernorms_w_bl "Village mean: own_gendernorms_w_bl"
							

						*** 2.7. Baseline summary indices ***

						***** 2.7.1. Men's likelihood of violence *****
						rename t1_intim_disrespect_m_bl t1_intim_disresp_m_bl
						rename t5_intim_impt_decision_m_bl t5_intim_imptdec_m_bl
						global men_beat_likely 		"s1_disrespect_m_bl s2_threat_leaving_m_bl s3_cheating_m_bl s4_flirting_m_bl s5_spend_money_m_bl s6_mock_m_bl s7_control_m_bl s8_interrupt_m_bl s9_impt_decision_m_bl s10_leaving_m_bl "
						global men_likley_intimid 	"t1_intim_disresp_m_bl t2_intim_thrtleav_m_bl t3_intim_flirting_m_bl t4_intim_ridicule_m_bl t5_intim_imptdec_m_bl"
						clonevar	beat_likly1	= 	s1_disrespect_m_bl
						clonevar	beat_likly2 	= s2_threat_leaving_m_bl
						clonevar	beat_likly3 	= s3_cheating_m_bl
						clonevar	beat_likly4 	= s4_flirting_m_bl
						clonevar	beat_likly5 	= s5_spend_money_m_bl
						clonevar	beat_likly6 	= s6_mock_m_bl
						clonevar	beat_likly7 	= s7_control_m_bl
						clonevar	beat_likly8 	= s8_interrupt_m_bl
						clonevar	beat_likly9 	= s9_impt_decision_m_bl
						clonevar	beat_likly10 	= s10_leaving_m_bl
						clonevar	beat_likly11 	= t1_intim_disresp_m_bl
						clonevar	beat_likly12 	= t2_intim_thrtleav_m_bl
						clonevar	beat_likly13 	= t3_intim_flirting_m_bl
						clonevar	beat_likly14 	= t4_intim_ridicule_m_bl
						clonevar	beat_likly15 	= t5_intim_imptdec_m_bl

						* First, convert to z scores using the control group (signs are already switched)
						forvalues count = 1/15 {
							su beat_likly`count' 	if couple_type == 0
										
							local MyMean 	= r(mean)
							local MySD 		= r(sd)
										
							gen beat_likly`count'_z 	= (beat_likly`count' - `MyMean')/`MySD'
						}
								
						* Second, impute missing values at the treatment assignment group mean
						forvalues count = 1/15 {
							capture drop YHatTemp
							
							reg beat_likly`count'_z i.couple_type
							predict YHatTemp 

							replace beat_likly`count'_z 	= YHatTemp if beat_likly`count'_z == .
						}
										
						* Third, calculate the covariance matrix and the weights
						correl beat_likly*_z , covar
						matrix MyCovar_beat_likl 	= r(C)	
						matrix CovarInv_beat_likl   	= syminv(MyCovar_beat_likl)
						matrix MyOnes_beat_likl  	= J(rowsof(CovarInv_beat_likl), 1, 1)
						matrix MyWeights_beat_likl  	= syminv(MyOnes_beat_likl' * CovarInv_beat_likl * MyOnes_beat_likl) * (MyOnes_beat_likl' * CovarInv_beat_likl)

						* Finally, create weighted variables from matrix weights
						svmat MyWeights_beat_likl, names(weight_beat_likl)
						forvalues count = 1/4 {
							gen weighted_beat_likl_`count' 	= beat_likly`count'_z * weight_beat_likl`count'[1]
						}
						egen  	WeightedVar_beat_likl_m_bl 	= rsum(weighted*)
						label var WeightedVar_beat_likl_m "BL Index: men's likelihood of becoming violent or intimidating"
						drop beat_likly*
						drop weight_beat_likl*
						drop weighted_beat_likl_*

								
						***** 2.7.2. Men's beliefs about community attitudes *****
						global beliefs_cmty_gend_m_bl "dd1_cmty_shame_hhwrk_m_bl dd2_cmty_obey_husb_m_bl dd3_cmty_womcontl_m_bl dd4_cmty_nointv_ipv_m_bl dd5_cmnty_jealousy_m_bl dd6_cmty_prohib_vist_m_bl dd7_cmty_btwife_m_bl dd8_cmty_force_sex_m_bl"
						clonevar		normsy1 = 	dd1_cmty_shame_hhwrk_m_bl	
						clonevar		normsy2=	dd2_cmty_obey_husb_m_bl
						clonevar		normsy3=	dd3_cmty_womcontl_m_bl
						clonevar		normsy4=	dd4_cmty_nointv_ipv_m_bl
						clonevar		normsy5=	dd5_cmnty_jealousy_m_bl
						clonevar		normsy6=	dd6_cmty_prohib_vist_m_bl
						clonevar		normsy7=	dd7_cmty_btwife_m_bl
						clonevar		normsy8=	dd8_cmty_force_sex_m_bl


						* First, convert to z scores using the control group (signs are already switched)
						forvalues count = 1/8 {
							su normsy`count' 	if couple_type == 0
										
							local MyMean 	= r(mean)
							local MySD 		= r(sd)
										
							gen normsy`count'_z 	= (normsy`count' - `MyMean')/`MySD'
						}
								
						* Second, impute missing values at the treatment assignment group mean
						drop YHat*

						forvalues count = 1/8 {
							capture drop YHatTemp
							
							reg normsy`count'_z i.couple_type
							predict YHatTemp 
							
							replace normsy`count'_z 	= YHatTemp if normsy`count'_z == .
						}
							
						* Third, calculate the covariance matrix and the weights
						correl normsy*_z , covar
						matrix MyCovar_norms 	= r(C)	
						matrix CovarInv_norms   	= syminv(MyCovar_norms)
						matrix MyOnes_norms  	= J(rowsof(CovarInv_norms), 1, 1)
						matrix MyWeights_norms  	= syminv(MyOnes_norms' * CovarInv_norms * MyOnes_norms) * (MyOnes_norms' * CovarInv_norms)

						* Finally, create weighted variables from matrix weights
						svmat MyWeights_norms, names(weight_norms)
						forvalues count = 1/8 {
								gen weighted_norms_`count' 	= normsy`count'_z * weight_norms`count'[1]
						}
						egen  	WeightedVar_norms_m_bl 	= rsum(weighted*)
						label var WeightedVar_norms_m_bl "BL Index: men's beliefs about conservative community norms and IPV prev"

						drop normsy*
						drop weight_norms*
						drop weighted_norms_*

							
						***** 2.7.. Women's beliefs about community attitudes *****
						global beliefs_cmty_gend_w "z1_cmty_shame_hsbnd_hhwrk_w_bl z2_cmty_obey_husband_w_bl z3_cmty_woman_control_man_w_bl z4_cmty_no_intervene_ipv_w_bl z5_cmnty_jealousy_w_bl z6_cmty_beat_wife_w_bl z7_cmty_force_sex_w_bl"

						clonevar		normsy1 = z1_cmty_shame_hsbnd_hhwrk_w_bl	
						clonevar		normsy2=	 z2_cmty_obey_husband_w_bl
						clonevar		normsy3=	z3_cmty_woman_control_man_w_bl
						clonevar		normsy4 = z4_cmty_no_intervene_ipv_w_bl	
						clonevar		normsy5=	 z5_cmnty_jealousy_w_bl
						clonevar		normsy6=	 z6_cmty_beat_wife_w_bl
						clonevar		normsy7=	z7_cmty_force_sex_w_bl	

						* First, convert to z scores using the control group (signs are already switched)
						forvalues count = 1/7 {
							su normsy`count' 	if couple_type == 0
										
							local MyMean 	= r(mean)
							local MySD 		= r(sd)
										
							gen normsy`count'_z 	= (normsy`count' - `MyMean')/`MySD'
						}
								
						* Second, impute missing values at the treatment assignment group mean
						drop YHat*

						forvalues count = 1/7 {
							capture drop YHatTemp
							
							reg normsy`count'_z i.couple_type
							predict YHatTemp 
							
							replace normsy`count'_z 	= YHatTemp if normsy`count'_z == .
						}			
							
						* Third, calculate the covariance matrix and the weights
						correl normsy*_z , covar
						matrix MyCovar_norms 	= r(C)	
						matrix CovarInv_norms   	= syminv(MyCovar_norms)
						matrix MyOnes_norms  	= J(rowsof(CovarInv_norms), 1, 1)
						matrix MyWeights_norms  	= syminv(MyOnes_norms' * CovarInv_norms * MyOnes_norms) * (MyOnes_norms' * CovarInv_norms)

						* Finally, create weighted variables from matrix weights
						svmat MyWeights_norms, names(weight_norms)
						forvalues count = 1/7 {
							gen weighted_norms_`count' 	= normsy`count'_z * weight_norms`count'[1]
						}
						egen  	WeightedVar_norms_w_bl 	= rsum(weighted*)
						label var WeightedVar_norms_w_bl "BL Index: women's beliefs about conservative community norms and IPV prev"
						drop normsy*
						drop weight_norms*
						drop weighted_norms_*
								
															
						****** 2.7.4. Women - relationship quality *****
						clonevar		relqualy1= 	m1_conflict_resolution_w_bl 
						clonevar		relqualy2=	 m2_emotion_sharing_w_bl
						clonevar		relqualy3=	m4_reaction_calm_w_bl
						clonevar 		relqualy4 =	m5_reaction_empathy_w_bl
						clonevar		relqualy5 = m3_partner_trust2_w_bl_p

						* First, convert to z scores using the control group (signs are already switched)
						forvalues count = 1/5 {
							su relqualy`count' 	if couple_type == 0						
							local MyMean 	= r(mean)
							local MySD 		= r(sd)					
							gen relqualy`count'_z 	= (relqualy`count' - `MyMean')/`MySD'
						}
								
						* Second, impute missing values at the treatment assignment group mean
						forvalues count = 1/5 {
							capture drop YHatTemp
							
							reg relqualy`count'_z i.couple_type
							predict YHatTemp
							
							replace relqualy`count'_z 	= YHatTemp if relqualy`count'_z == .
						}

						* Third, calculate the covariance matrix and the weights
						correl relqualy*_z , covar
						matrix MyCovar_relqual 	= r(C)	
						matrix CovarInv_relqual   	= syminv(MyCovar_relqual)
						matrix MyOnes_relqual  	= J(rowsof(CovarInv_relqual), 1, 1)
						matrix MyWeights_relqual 	= syminv(MyOnes_relqual' * CovarInv_relqual * MyOnes_relqual) * (MyOnes_relqual' * CovarInv_relqual)

						* Finally, create weighted variables from matrix weights
						svmat MyWeights_relqual, names(weight_relqual)
						forvalues count = 1/5 {
							gen weighted_relqual_`count' 	= relqualy`count'_z * weight_relqual`count'[1]
						}
						egen  	WeightedVar_relqual_w_bl 	= rsum(weighted*)
						label var WeightedVar_relqual_w_bl "BL Index: relationship quality - women"
						drop relqualy*
						drop weight_relqual*
						drop weighted_relqual_*		
							

						****** 2.7.5. Men - relationship quality *****
						clonevar	relqualy1= 	l1_conflict_resolution_m_bl  
						clonevar	relqualy2=	 l2_emotion_sharing_m_bl
						clonevar	relqualy3=	l3_partner_trust2_m_bl_p

						* First, convert to z scores using the control group (signs are already switched)
						forvalues count = 1/3 {
							su relqualy`count' 	if couple_type == 0						
							local MyMean 	= r(mean)
							local MySD 		= r(sd)					
							gen relqualy`count'_z 	= (relqualy`count' - `MyMean')/`MySD'
						}
								
						* Second, impute missing values at the treatment assignment group mean
							
						forvalues count = 1/3 {
							capture drop YHatTemp
							
							reg relqualy`count'_z i.couple_type
							predict YHatTemp
							
							replace relqualy`count'_z 	= YHatTemp if relqualy`count'_z == .
						}
											
						* Third, calculate the covariance matrix and the weights
						correl relqualy*_z , covar
						matrix MyCovar_relqual 	= r(C)	
						matrix CovarInv_relqual   	= syminv(MyCovar_relqual)
						matrix MyOnes_relqual  	= J(rowsof(CovarInv_relqual), 1, 1)
						matrix MyWeights_relqual 	= syminv(MyOnes_relqual' * CovarInv_relqual * MyOnes_relqual) * (MyOnes_relqual' * CovarInv_relqual)

						* Finally, create weighted variables from matrix weights
						svmat MyWeights_relqual, names(weight_relqual)
						forvalues count = 1/3 {
							gen weighted_relqual_`count' 	= relqualy`count'_z * weight_relqual`count'[1]
						}
						egen  	WeightedVar_relqual_m_bl 	= rsum(weighted*)
						label var WeightedVar_relqual_m_bl "BL Index: relationship quality - men"
						drop relqualy*
						drop weight_relqual*
						drop weighted_relqual_*		
									
								
						****** 2.7.6. Depression index outcome - men *****
						global dep_m_bl 	"cc1_pleasure_m_bl cc2_down_m_bl cc3_sleep_m_bl cc4_energy_m_bl cc5_appetite_m_bl cc6_failure_m_bl cc7_concentrate_m_bl cc8_movement_dep_m_bl cc9_hurt_self_m_bl"		

						foreach x of varlist  $dep_m_bl {
							tab `x', mi
							local r = `r' + 1
							clonevar dep_my`r'= `x' 
						}

						* First, convert to z scores using the control group (signs are already switched)
						forvalues count = 1/9 {
							su dep_my`count' 	if couple_type == 0
										
							local MyMean 	= r(mean)
							local MySD 		= r(sd)
										
							gen dep_my`count'_z 	= (dep_my`count' - `MyMean')/`MySD'
						}

						* Second, impute missing values at the treatment assignment group mean
						forvalues count = 1/9 {
							capture drop YHatTemp
									
							reg dep_my`count'_z i.couple_type
							predict YHatTemp
									
							replace dep_my`count'_z 	= YHatTemp if dep_my`count'_z == .
						}						
											
						* Third, calculate the covariance matrix and the weights
						correl dep_my*_z , covar
						matrix MyCovar_dep_m 	= r(C)	
						matrix CovarInv_dep_m   	= syminv(MyCovar_dep_m)
						matrix MyOnes_dep_m  	= J(rowsof(CovarInv_dep_m), 1, 1)
						matrix MyWeights_dep_m  	= syminv(MyOnes_dep_m' * CovarInv_dep_m * MyOnes_dep_m) * (MyOnes_dep_m' * CovarInv_dep_m)

						* Finally, create weighted variables from matrix weights
						svmat MyWeights_dep_m, names(weight_dep_m)
						forvalues count = 1/9 {
							gen weighted_dep_m_`count' 	= dep_my`count'_z * weight_dep_m`count'[1]
						}
						egen  	WeightedVar_dep_m_bl 	= rsum(weighted_dep_m*)
						label var WeightedVar_dep_m_bl "BL Index: depression - men"

						drop 	dep_my*
						drop 	weight_dep_m*
						drop  	weighted_dep_m*
					
	












***************************************************************
* 3. Endline variable creation
***************************************************************	

*** 3.1. IPV variables ***
* Emotional IPV
gen 		emo_violence_dum=.
replace 	emo_violence_dum=.r 	if  s6_public_humiliation_w==.r | s8_insult_w==.r 
replace 	emo_violence_dum=0 		if s6_public_humiliation_w==0 & s8_insult_w==0
replace 	emo_violence_dum=1 		if s6_public_humiliation_w==1 | s6_public_humiliation_w==2 | s6_public_humiliation_w==3 | /*s7_threat_w==1 | s7_threat_w==2 |s7_threat_w==3 | */ s8_insult_w==1 | s8_insult_w==2 | s8_insult_w==3
label val  	emo_violence_dum 		yesno
label var	emo_violence_dum		"Experienced at least 1 form of emotional violence in last 6m"

* Physical IPV
gen 		physical_violence_dum =.
replace 	physical_violence_dum=.r 	if s10_slapped_freq_w==.r | s11_twisted_arm_freq_w==.r | s12_punched_freq_w==.r | s13_beaten_freq_w==.r | s14_strangled_freq_w==.r | s15_attacked_weapon_freq_w==.r 
replace 	physical_violence_dum= 0 	if s10_slapped_freq_w==0 & s11_twisted_arm_freq_w==0 & s12_punched_freq_w==0 & s13_beaten_freq_w==0 & s14_strangled_freq_w==0 & s15_attacked_weapon_freq_w==0 
replace 	physical_violence_dum=1		if /*s9_pushed_freq_w==1 | */ (s10_slapped_freq_w>=1 & s10_slapped_freq_w<=3) | (s11_twisted_arm_freq_w>=1 & s11_twisted_arm_freq_w<=3)  | (s12_punched_freq_w>=1 & s12_punched_freq_w<=3) | (s13_beaten_freq_w>=1 & s13_beaten_freq_w<=3) | (s14_strangled_freq_w>=1 & s14_strangled_freq_w<=3) | (s15_attacked_weapon_freq_w>=1 & s15_attacked_weapon_freq_w <=3) 
label val  	physical_violence_dum 	yesno
label var	physical_violence_dum	"Experienced at least 1 form of physical violence in last 6m"

* Sexual IPV
gen 	sexual_violence_dum =.
replace sexual_violence_dum =.r if s20_forced_sex_phys_freq_w==.r | s21_forced_sex_fear_freq_w==.r | s22_forced_degrading_sex_freq_w==.r
replace sexual_violence_dum = 0 if s20_forced_sex_phys_freq_w==0 & s21_forced_sex_fear_freq_w==0 & s22_forced_degrading_sex_freq_w==0
replace sexual_violence_dum=1 if (s20_forced_sex_phys_freq_w>=1 & s20_forced_sex_phys_freq_w<=3) | (s21_forced_sex_fear_freq_w>=1 & s21_forced_sex_fear_freq_w<=3) | (s22_forced_degrading_sex_freq_w>=1 & s22_forced_degrading_sex_freq_w<=3)
label val  	sexual_violence_dum 		yesno
label var	sexual_violence_dum			"Experienced at least 1 form of sexual violence in last 6m"

* Rename degrading sex variable:
gen 	s22_degrd_sex_freq_w=s22_forced_degrading_sex_freq_w
drop 	s22_forced_degrading_sex_freq_w

* Physical AND/ OR sexual violence
gen 	phys_or_sex_vio = .
replace phys_or_sex_vio=0 	if physical_violence_dum==0 & sexual_violence_dum==0
replace phys_or_sex_vio = 1 if physical_violence_dum==1 | sexual_violence_dum==1
label val  	phys_or_sex_vio 		yesno
label var	phys_or_sex_vio			"Experienced at least 1 form of physical and/or sexual violence in last 6m"

* Controlling behaviours 
gen 		emo_contrl_behav_dum=.
replace 	emo_contrl_behav_dum=.r 	if s1_jealousy_w==.r | s2_unfaithful_accuse_w==.r | s3_prevent_friends_w==.r | s4_limit_family_contact_w==.r | s5_always_know_location_w==.r 
replace 	emo_contrl_behav_dum=0 		if s1_jealousy_w==0 & s2_unfaithful_accuse_w==0 & s3_prevent_friends_w==0 & s4_limit_family_contact_w==0 & s5_always_know_location_w==0 
replace 	emo_contrl_behav_dum=1 		if s1_jealousy_w==1 | s2_unfaithful_accuse_w==1 | s3_prevent_friends_w==1 | s4_limit_family_contact_w==1 | s5_always_know_location_w==1 
label val  	emo_contrl_behav_dum 		yesno
label var	emo_contrl_behav_dum		"Experienced at least 1 form of controlling behaviours in last 6m"

* Economic coercion
gen 		eco_coercion_dum=.
replace		eco_coercion_dum=.r 	if refused_give_money_w==.r | no_money_w==.r  
replace		eco_coercion_dum= 0 	if refused_give_money_w==0 & no_money_w==0 
replace 	eco_coercion_dum=1 		if (refused_give_money_w>=1 & refused_give_money_w<=3)  |  (no_money_w>=1 & no_money_w<=3) 
label val  	eco_coercion_dum 		yesno
label var	eco_coercion_dum		"Experienced at least 1 form of economic coercion in last 6m"

* Refusal rates
local ipv_outcomes s1_jealousy_w s2_unfaithful_accuse_w s3_prevent_friends_w s4_limit_family_contact_w s5_always_know_location_w s6_public_humiliation_w s7_threat_w s8_insult_w  s9_pushed_freq_w s10_slapped_freq_w s11_twisted_arm_freq_w s12_punched_freq_w s13_beaten_freq_w s14_strangled_freq_w s15_attacked_weapon_freq_w s17_injuries_minor_w s18_injuries_serious_vio_w s19_prevent_working_vio_w s20_forced_sex_phys_freq_w s21_forced_sex_fear_freq_w s22_degrd_sex_freq_w

foreach x of varlist `ipv_outcomes'  {
	gen ref_`x' 	= 0 if (`x'!=.)
	replace ref_`x' =1 	if `x'==.r
	label var ref_`x' "Refused to answer `x'"
}

gen emo_vio_ref= 0
replace emo_vio_ref= 1 if ref_s6_public_humiliation_w==1 | ref_s8_insult_w==1

gen phys_vio_ref= 0
replace phys_vio_ref= 1 if ref_s10_slapped_freq_w==1| ref_s11_twisted_arm_freq_w==1| ref_s12_punched_freq_w==1| ref_s13_beaten_freq_w==1| ref_s14_strangled_freq_w==1| ref_s15_attacked_weapon_freq_w==1

gen sex_vio_ref= 0
replace sex_vio_ref= 1 if ref_s20_forced_sex_phys_freq_w==1 |ref_s21_forced_sex_fear_freq_w==1| ref_s22_degrd_sex_freq_w==1

* Extra robustness variable: code all refuse as yes
gen emo_vio_act_refeqlyes= emo_violence_dum
replace emo_vio_act_refeqlyes= 1 if ref_s6_public_humiliation_w==1 | ref_s8_insult_w==1  
label var	emo_vio_act_refeqlyes		"EL Emotional vio: all refuses coded as yes "

gen phys_vio_refeqlyes= physical_violence_dum
replace phys_vio_refeqlyes= 1 if ref_s10_slapped_freq_w==1| ref_s11_twisted_arm_freq_w==1| ref_s12_punched_freq_w==1| ref_s13_beaten_freq_w==1| ref_s14_strangled_freq_w==1| ref_s15_attacked_weapon_freq_w==1
label var	phys_vio_refeqlyes		"EL Physical vio: all refuses coded as yes "	

gen sex_vio_act_refeqlyes= sexual_violence_dum
replace sex_vio_act_refeqlyes= 1 if ref_s20_forced_sex_phys_freq_w==1 |ref_s21_forced_sex_fear_freq_w==1| ref_s22_degrd_sex_freq_w==1
label var	sex_vio_act_refeqlyes		"EL Sexual vio: all refuses coded as yes "		

* Extra robustness variable: code all refuse as no
gen emo_vio_act_refeqlno= emo_violence_dum
replace emo_vio_act_refeqlno= 0 if ref_s20_forced_sex_phys_freq_w==1 | ref_s8_insult_w==1  
label var	emo_vio_act_refeqlno		"EL Emotional vio: all refuses coded as no "		

gen phys_vio_refeqlno= physical_violence_dum
replace phys_vio_refeqlno= 0 if ref_s10_slapped_freq_w==1| ref_s11_twisted_arm_freq_w==1| ref_s12_punched_freq_w==1| ref_s13_beaten_freq_w==1| ref_s14_strangled_freq_w==1| ref_s15_attacked_weapon_freq_w==1
label var	phys_vio_refeqlno		"EL Physical vio: all refuses coded as no "	

gen sex_vio_act_refeqlno= sexual_violence_dum
replace sex_vio_act_refeqlno= 0 if ref_s20_forced_sex_phys_freq_w==1 |ref_s21_forced_sex_fear_freq_w==1| ref_s22_degrd_sex_freq_w==1
label var	sex_vio_act_refeqlno		"EL Sexual vio: all refuses coded as no "		

* Generate dummies for each violence type
rename s20_forced_sex_phys_freq_w s20_frc_sex_freq_w
rename s15_attacked_weapon_freq_w s15_attacked_wpn_freq_w
rename s21_forced_sex_fear_freq_w s21_frc_sex_fear_freq_w

global emo_vio "s6_public_humiliation_w  s8_insult_w " 
global phys_vio " s10_slapped_freq_w s11_twisted_arm_freq_w s12_punched_freq_w s13_beaten_freq_w s14_strangled_freq_w s15_attacked_wpn_freq_w "	
global sexual_vio "s20_frc_sex_freq_w  s21_frc_sex_fear_freq_w  s22_degrd_sex_freq_w"  

foreach x of varlist $emo_vio $phys_vio $sexual_vio {
	gen 	d_`x'=. 	if (`x'==.)
	replace d_`x'=.r 	if (`x'==.r)
	replace d_`x'=0 	if `x'==0
	replace d_`x'=1 	if `x'==1 | `x'==2 | `x'==3 
}

egen 	emo_vio_numb= 	rowtotal	(d_s6_public_humiliation_w d_s8_insult_w )
replace emo_vio_numb=. 	if 	emo_violence_dum==.

egen 	phys_vio_numb= 	rowtotal	(d_s10_slapped_freq_w d_s11_twisted_arm_freq_w d_s12_punched_freq_w d_s13_beaten_freq_w d_s14_strangled_freq_w d_s15_attacked_wpn_freq_w)
replace phys_vio_numb=. if 	physical_violence_dum==.

egen 	sex_vio_numb= 	rowtotal	(d_s20_frc_sex_freq_w d_s21_frc_sex_fear_freq_w d_s22_degrd_sex_freq_w)
replace sex_vio_numb=. 	if 	sexual_violence_dum==.


* Violence against men dummy
gen 	physical_violence_m=.
replace physical_violence_m= 0 		if u2_ptnr_violent_freq_m==0
replace physical_violence_m= 1 		if (u2_ptnr_violent_freq_m>=1 & u2_ptnr_violent_freq_m<=3)

gen 	emo_violence_m=.
replace emo_violence_m= 0 	if u4_ptnr_emot_abused_freq_m==0
replace emo_violence_m= 1 	if (u4_ptnr_emot_abused_freq_m>=1 & u4_ptnr_emot_abused_freq_m<=3)


* Violence frequency
local vio_freq s10_slapped_freq_w s11_twisted_arm_freq_w s12_punched_freq_w s13_beaten_freq_w s14_strangled_freq_w s15_attacked_wpn_freq_w s20_frc_sex_freq_w s21_frc_sex_fear_freq_w s22_degrd_sex_freq_w
foreach x of varlist `vio_freq' {
	tab `x',mi
	gen `x'_sof = .
	replace `x'_sof=1 if `x' ==2 | `x'==3
	replace `x'_sof=0 if `x'==0 | `x'==1
	replace `x'_sof=.r if `x'==.r
	label var `x'_sof "Sometimes or often experienced `x'"
}

* Increasing regression sample by changing denominator for some vars
gen s23_injuries_sex_w=0
replace s23_injuries_sex_w=1 if s23_injuries_force_sex_w==1
gen s17_injuries_minor=0
replace s17_injuries_minor=1 if s17_injuries_minor_w==1

gen oo5_m5_cnsl_refer_w_all = 0
replace oo5_m5_cnsl_refer_w_all=1 if oo5_meta5_counsellor_referal_w==1

* Shorten variable names
rename d_s6_public_humiliation_w 		public_humiliation_w  
rename d_s8_insult_w 					insult_w 
rename d_s10_slapped_freq_w 			slapped_w
rename d_s11_twisted_arm_freq_w 		twisted_arm_w
rename d_s12_punched_freq_w 			punched_w
rename d_s13_beaten_freq_w 				beaten_w
rename d_s14_strangled_freq_w 			strangled_w
rename d_s15_attacked_wpn_freq_w 		attacked_wpn_w  
rename d_s20_frc_sex_freq_w 			forced_sex_w 
rename d_s21_frc_sex_fear_freq_w  		forced_sex_fear_w
rename d_s22_degrd_sex_freq_w 			degrd_sex_w
rename s10_slapped_freq_w_sof slapped_w_sof
rename s11_twisted_arm_freq_w_sof twisted_arm_w_sof
rename s12_punched_freq_w_sof punched_w_sof
rename s13_beaten_freq_w_sof beaten_w_sof
rename s14_strangled_freq_w_sof strangled_w_sof
rename s15_attacked_wpn_freq_w_sof attacked_wpn_w_sof   
rename s20_frc_sex_freq_w_sof forced_sex_w_sof 
rename s21_frc_sex_fear_freq_w_sof forced_sex_fear_w_sof 
rename s22_degrd_sex_freq_w_sof degrd_sex_w_sof  
rename oo1_meta2_signs_phys_pain_w 		oo1_m2_signphyspain_w
rename oo5_meta5_counsellor_referal_w 	oo5_m5_cnsl_refer_w
rename oo6_meta6_spoke_counsel_w 		oo6_m6_spk_cnsl_w

label var oo1_meta1_distress_w "Wife shows signs of distress"
label var oo5_m5_cnsl_refer_w_all "Wife was referred to counsellor"
label var oo6_m6_spk_cnsl_w "Wife chose to speak to counsellor"
label var oo1_m2_signphyspain_w "Wife shows signs of physical pain or injuries"


	*** 3.2. IPV attitudes ***
	rename t1_intim_disrespect_m t1_intim_disresp_m
	rename t2_intim_threat_leaving_m t2_intim_thrtleav_m
	rename t5_intim_impt_decision_m t5_intim_imptdec_m

	* Likelihood of men becoming vioelnt: 
	global men_beat_likely 		"s1_disrespect_m s2_threat_leaving_m s3_cheating_m s4_flirting_m s5_spend_money_m s6_mock_m s7_control_m s8_interrupt_m s9_impt_decision_m s10_leaving_m"
	global men_likely_intimid 	"t1_intim_disresp_m t2_intim_thrtleav_m t3_intim_flirting_m t4_intim_ridicule_m t5_intim_imptdec_m"

	* Men's intention to commit violence: higher score= worse 
	foreach x of varlist $men_beat_likely $men_likely_intimid {
		gen 		`x'_lkly=.
		replace  	`x'_lkly=0  	if (`x'==1 | `x'==2)
		replace  	`x'_lkly=1  	if (`x'==3 | `x'==4)
		label var `x'_lkly "Dummy men likely violent -`x'"
	}
	egen reasons_lklyvio_m_eg = rowtotal (s1_disrespect_m_lkly s2_threat_leaving_m_lkly s3_cheating_m_lkly s4_flirting_m_lkly s5_spend_money_m_lkly s6_mock_m_lkly s7_control_m_lkly s8_interrupt_m_lkly s9_impt_decision_m_lkly s10_leaving_m_lkly t1_intim_disresp_m_lkly t2_intim_thrtleav_m_lkly t3_intim_flirting_m_lkly t4_intim_ridicule_m_lkly t5_intim_imptdec_m_lkly)
	replace reasons_lklyvio_m_eg=. if s1_disrespect_m_lkly==. & s2_threat_leaving_m_lkly==. & s3_cheating_m_lkly==. & s4_flirting_m_lkly==. & s5_spend_money_m_lkly==. & s6_mock_m_lkly==. & s7_control_m_lkly==. & s8_interrupt_m_lkly==. & s9_impt_decision_m_lkly==. & s10_leaving_m_lkly==. & t1_intim_disresp_m_lkly==. & t2_intim_thrtleav_m_lkly==. & t3_intim_flirting_m_lkly==. & t4_intim_ridicule_m_lkly==. & t5_intim_imptdec_m_lkly==. 
	label 	var		reasons_lklyvio_m_eg	"Number of hypothetical situations men would be likley to become violent- out of 15"

	* Create positive variables - invert so more is better
	foreach var of varlist dd5_happiness_post_economic_w confident_to_disagree_w feel_respected_w respect_partner_w l3_partner_trust2_w overall_happiness_m respect_partner_m feel_respected_m confident_to_disagree_m  l3_partner_trust2_m  {
		gen `var'_p=.
		replace `var'_p=0 if `var'==4
		replace `var'_p=1 if `var'==3
		replace `var'_p=2 if `var'==2
		replace `var'_p=3 if `var'==1
		label var `var'_p  "Positive_`var'"
	} 
	rename dd5_happiness_post_economic_w_p overall_happiness_w_p

	foreach var of varlist  marital_life_satisfied_w  marital_life_satisfied_m {
		gen `var'_p=.
		replace `var'_p=1 if `var'==5
		replace `var'_p=2 if `var'==4
		replace `var'_p=3 if `var'==3
		replace `var'_p=4 if `var'==2
		replace `var'_p=5 if `var'==1
		label var `var'_p  "Positive_`var'"
	} 

	* Depression score -  men
	gen dep_score_m= 	cc1_pleasure_m+ cc2_down_m +cc3_sleep_m +cc4_energy_m +cc5_appetite_m +cc6_failure_m +cc7_concentrate_m +cc8_movement_dep_m +cc9_hurt_self_m
	label 	var			dep_score_m		"EL_Men- Total depression score"
	gen mod_sever_dep_m		=0 
	replace mod_sever_dep_m	=1 if dep_score_m>=10
	label var  mod_sever_dep_m "Moderate to severe depression"

	* Gender attitudes - own Gender inequitable Norms-  NOTE: Higher score= more gender INEQUITABLE. 0 = more gender equitable
	* Men
	gen 			own_gendernorms_m	=.
	replace 		own_gendernorms_m	= k5_shame_husband_hhwork_m +  k6_obey_husband_m + k7_woman_control_man_m + k8_ipv_private_m	
	label 	var		own_gendernorms_m	"Men: Number of gender inequitable attitudes"
	tab own_gendernorms_m,mi

	//Gen separate comparable own_norms question for husband wife attitude gap because 1 question was dropped at endline

	* IPV justified? How many time is ipv justified out of 5? More is worse.
	gen 			own_ipv_justified_m	= q1_beating_neglect_children_m + q2_beating_refusing_sex_m + q3_beating_disobey_m + q4_beating_burn_food_m + q5_beating_suspect_unfaithful_m
	label 	var		own_ipv_justified_m	"Men: Number of reasons husband thinks IPV is justified"

	* Refusing sex justified? More is better
	gen 			own_refusesex_m	= r1_refuse_know_unfaithful_m+ r2_refuse_drunk_m + r3_refuse_mistreatment_m  
	label 	var		own_refusesex_m	"Men: Number of reasons husband thinks a wife refusing sex is justified"


	* Women
	gen 			own_gendernorms_w	=.
	replace 		own_gendernorms_w	= l1_shame_husband_hhwork_w +  l2_obey_husband_w + /*l3_woman_control_man_w +*/ l4_ipv_private_w
	label 	var		own_gendernorms_w	"Women: Number of gender inequitable attitudes "

	* IPV justified? How many time is ipv justified out of 5? More is worse.
	gen 			own_ipv_justified_w	= q1_beating_neglect_children_w + q2_beating_refusing_sex_w + q3_beating_disobey_w + q4_beating_burn_food_w + q5_beating_suspect_unfaithful_w
	label 	var		own_ipv_justified_w	"Women: Number of situations wife thinks IPV is justified"

	* Refusing sex justified? More is better
	gen 			own_refusesex_w	= r1_refuse_know_unfaithful_w+ r2_refuse_drunk_w + r3_refuse_mistreatment_w  
	label 	var		own_refusesex_w	"Women: Number of situations wife thinks refusing sex is justified"


	** Making equitable equivalents to make the gender gap calculations
	* Gender equitable attitudes re. IPV jusitifed? How many time is IPV NOT justified out of 5? Higher number is more gender equaitable attitudes expressed
		
	* Women
	foreach var of varlist q1_beat_neglect_child_w  q2_beating_refusing_sex_w  q3_beating_disobey_w  q4_beating_burn_food_w  q5_beat_suspect_unfaith_w {
		gen `var'_p=0
		replace `var'_p=1 if `var'==0
		replace `var'_p=0 if `var'==1
	} 
	gen own_ipv_justified_w_equit= q1_beat_neglect_child_w_p+ q2_beating_refusing_sex_w_p+ q3_beating_disobey_w_p+ q4_beating_burn_food_w_p+ q5_beat_suspect_unfaith_w_p

	foreach var of varlist l1_shame_husband_hhwork_w   l2_obey_husband_w   l4_ipv_private_w {
		gen `var'_p=0
		replace `var'_p=1 if `var'==0
		replace `var'_p=0 if `var'==1
	} 
	gen own_gendernorms_w_equit= l1_shame_husband_hhwork_w_p+ l2_obey_husband_w_p+ l4_ipv_private_w_p

	* Men	
	foreach var of varlist q1_beat_neglect_child_m  q2_beating_refusing_sex_m  q3_beating_disobey_m  q4_beating_burn_food_m  q5_beat_suspect_unfaith_m {
		gen `var'_p=0
		replace `var'_p=1 if `var'==0
		replace `var'_p=0 if `var'==1
	} 
	gen own_ipv_justified_m_equit= q1_beat_neglect_child_m_p+ q2_beating_refusing_sex_m_p+ q3_beating_disobey_m_p+ q4_beating_burn_food_m_p+ q5_beat_suspect_unfaith_m_p

	foreach var of varlist k5_shame_husband_hhwork_m   k6_obey_husband_m   k8_ipv_private_m {
		gen `var'_p=0
		replace `var'_p=1 if `var'==0
		replace `var'_p=0 if `var'==1
	} 
	gen own_gendernorms_m_equit= k5_shame_husband_hhwork_m_p+ k6_obey_husband_m_p+ k8_ipv_private_m_p
	
	* Dummy - wife got more progressive, husband got more conservative
	gen wifegtmoreprog_gndrnm_dum=  (own_gendernorms_w_equit-own_gendernorms_w_equit_bl)>0 & (own_gendernorms_m_equit-own_gendernorms_m_equit_bl)<0
	label 	var	wifegtmoreprog_gndrnm_dum		"Friction dummy: wife got more progressive gender atts. Husb got more conservative"
	gen wifegtmoreprog_ipvjust_dum=  (own_ipv_justified_w_equit-own_ipv_justified_w_equit_bl)>0 & (own_ipv_justified_m_equit-own_ipv_justified_m_equit_bl) <0
	label 	var	wifegtmoreprog_ipvjust_dum		"Friction dummy: wife got more progressive ipv atts. Husb got more conservative"

	* Differences between spouses at EL: Generate couples gap score
	gen gap_gndrnrms= (own_gendernorms_w_equit-own_gendernorms_m_equit)
	label 	var	gap_gndrnrms		"Attitude Gap wife fewer gender inequitable atts than husb"

	gen gap_ipvjust= (own_ipv_justified_w_equit -own_ipv_justified_m_equit)
	label 	var	gap_ipvjust		"Attitude Gap wife fewer ipv acceptability atts than husb"


	* Windsorize knowledge about IPV in village
	foreach x of varlist knowledge_ipv_m knowledge_ipv_women_m {
				winsor2 `x' , cuts(0 99) suffix(_win) 
	}



		*** 3.3. Decision-making and behavior ***

		* 3.3.1. Decision-making ang agency *
		* Decision making - women
		global decision_input_w "decision_input_income_w decision_input_hh_income_w decision_input_hh_expenses_w decision_input_childbearing_w "

		clonevar 	dec_input_inc_w 	= decision_input_income_w
		clonevar 	dec_input_hh_inc_w	= decision_input_hh_income_w
		clonevar 	dec_input_hh_exp_w 	= decision_input_hh_expenses_w
		clonevar 	dec_input_child_w	= decision_input_childbearing_w

		global decision_input_w "dec_input_inc_w dec_input_hh_inc_w dec_input_hh_exp_w dec_input_child_w "

		foreach var of varlist  $decision_input_w   {
			gen `var'_role=.
			replace `var'_role=0 if /*`var'==-97 |*/ (`var'>3 & `var'<9)
			replace `var'_role=1 if (`var'>0 & `var'<4)
			label var `var'_role  "Wife has input in decision_`var'"
		} 

		* Decision making - men
		global decision_input_m "decision_input_income_m decision_input_hh_income_m decision_input_hh_expenses_m decision_input_childbearing_m "

		clonevar 	dec_input_inc_m 	= decision_input_income_m
		clonevar 	dec_input_hh_inc_m	= decision_input_hh_income_m
		clonevar 	dec_input_hh_exp_m 	= decision_input_hh_expenses_m
		clonevar 	dec_input_child_m	= decision_input_childbearing_m

		global decision_input_m "dec_input_inc_m dec_input_hh_inc_m dec_input_hh_exp_m dec_input_child_m "
		foreach var of varlist  $decision_input_m   {
			gen `var'_role=.
			replace `var'_role=0 if (`var'>1 & `var'<8)
			replace `var'_role=1 if `var'==1 
			label var `var'_role  "Husband makes sole decision_`var'"
		} 

		* Want more decision making
		rename decision_ideal_hh_expenses_w dec_idl_hhexpns_w
		rename decision_ideal_childbearing_w dec_idl_chldbr_w
		rename decision_ideal_hh_expenses_m dec_idl_hhexpns_m
		rename decision_ideal_childbearing_m dec_idl_chldbr_m

		foreach x of varlist dec_idl_hhexpns_w dec_idl_chldbr_w dec_idl_hhexpns_m dec_idl_chldbr_m  {
			gen wantmre_`x' = .
			replace wantmre_`x'=0 if `x'==-99 /*| `x'==-97 */ | `x'==1 | `x'==3
			replace wantmre_`x'=1 if `x'==2
			label var wantmre_`x' "Want more input in decision `x'"
		}
		
		* 3.3.2. Alcohol consumption *	
		* Alcohol dummy based on v1_alcohol_freq_m v2_alcohol_excess_m drinking_m t1_partner_alcohol_use_w drinking_w
		gen 		v2_alcohol_excess_dum_m=.
		replace 	v2_alcohol_excess_dum_m=0 	if v2_alcohol_excess_m==0
		replace 	v2_alcohol_excess_dum_m=1 	if (v2_alcohol_excess_m>=1 & v2_alcohol_excess_m<=3)

		gen 		t1_ptnr_alc_som_always_w=.
		replace  	t1_ptnr_alc_som_always_w=0  if (t1_partner_alcohol_use_w>=0 & t1_partner_alcohol_use_w<=2)
		replace  	t1_ptnr_alc_som_always_w=1  if (t1_partner_alcohol_use_w>=3 & t1_partner_alcohol_use_w<=5)
				 
		* Make full sample for alcohol strategic reporting analysis
		global alcohol_makefullsample "v2_alcohol_excess_dum_m_bl v2_alcohol_excess_m_bl t2_ptnr_drinktoomuch_w_bl alcohol_daily_m v2_alcohol_excess_dum_m v2_alcohol_excess_m  t2_ptnr_drnks_toomuch_w "
		foreach x of varlist aa12_fth_phipv_m_bl_dm $alcohol_makefullsample  {
			gen `x'_ful=0 if `x'==.
			replace `x'_ful=`x' if `x'!=.
			lab 	var `x'_ful	"Full sample `x'"
		}
		gen v2_alcoholexcs_dum_m_ful = v2_alcohol_excess_dum_m_ful

		gen t2_ptnrdrnk_toomch_w_ful = t2_ptnr_drnks_toomuch_w_ful
		gen ptnr_drnktoomuch_w= 0 if t2_ptnr_drnks_toomuch_w_ful==0 | t2_ptnr_drnks_toomuch_w_ful==. 
		replace ptnr_drnktoomuch_w=1 if t2_ptnr_drnks_toomuch_w_ful==1 | t2_ptnr_drnks_toomuch_w_ful==2 | t2_ptnr_drnks_toomuch_w_ful==3

		gen t2_ptnrdrnk_toomch_w_bl = t2_ptnr_drinktoomuch_w_bl_ful
		gen ptnr_drnktoomuch_w_bl= 0 if t2_ptnr_drinktoomuch_w_bl_ful==0 | t2_ptnr_drinktoomuch_w_bl_ful==. 
		replace ptnr_drnktoomuch_w_bl=1 if t2_ptnr_drinktoomuch_w_bl_ful==1 | t2_ptnr_drinktoomuch_w_bl_ful==2 | t2_ptnr_drinktoomuch_w_bl_ful==3

		rename v2_alcohol_excess_m_bl_ful alc_excess_m_bl 
		rename v2_alcohol_excess_m_ful alc_excess_m

		*3.3.3. Other behavior *
		* IPV reporting
		recode ipv_report_2_w (2 = 1  "No, I don’t feel comfortable meddling") (1 = 0 "Yes I'd report"), gen(ipv_report_2_w_cln)
		recode ipv_report_2_m (2 = 1  "No, I don’t feel comfortable meddling") (1 = 0 "Yes I'd report"), gen(ipv_report_2_m_cln)

		* Husband took money		
		gen husb_takemoney_hhben_w = 0
		replace husb_takemoney_hhben_w=1 if household_benefit_w==1 | household_benefit_w==2 | household_benefit_w==3
		label var husb_takemoney_hhben_w "Husband taken money set aside for hh benefits on himself"

		* Domestic housework and carework - minutes they were primary activity
		foreach x of varlist time_400_m - time_2730_m	time_400_w -time_2730_w {
			gen `x'_caredom_min = 0 
			replace `x'_caredom_min = 30 if (`x' =="adultcare" | `x' =="childcare" | `x' =="cooking" | `x' =="domestic")
		}
		egen domestic_care_mins_w = rowtotal (time_400_w_caredom_min -time_2730_w_caredom_min)
		label 	var 	domestic_care_mins_w	"Minutes doing domestic or carework as primary activity"	
		egen domestic_care_mins_m = rowtotal (time_400_m_caredom_min -time_2730_m_caredom_min)
		label 	var 	domestic_care_mins_m	"Minutes doing domestic or carework as primary activity"	

		*Formalized marriage from BL to EL
		gen formalized_marr_w_blel=0
		replace formalized_marr_w_blel=1 if d11_marriage_type_2_w_bl==0 & 	e12_married_12months_w==1 	
		lab var formalized_marr_w_blel "Entered formal legal marriage from BL to EL"
		replace formalized_marr_w_blel = . if civil_legal_marriage_bl == 1
			
		gen formalized_marr_m_blel=0
		replace formalized_marr_m_blel=1 if d11_marriage_type_2_w_bl==0 & 	e12_married_12months_m==1 	
		lab var formalized_marr_m_blel "Entered formal legal marriage from BL to EL-Men"
		replace formalized_marr_m_blel = . if civil_legal_marriage_bl == 1

		lab val formalized_marr_w_blel yesno
		replace formalized_marr_w_blel=. if d3_marital_status_w==.


			*** 3.4. Economic outcomes ***

			* 3.4.1. ASSETS
			* Household asset ownership - sum of all hh assets types of assets: 
			egen hh_assets_tot_num= rowtotal(hh_radios_w  hh_phones_w  hh_scooters_w  hh_bicycles_w  hh_televisions_w  hh_mats_w)
			lab var hh_assets_tot_num "Total number of assets household owns"

			* Wife's asset ownership - total number of wife's total assets in household: 
			egen wife_assets_tot_num= rowtotal (personal_radios_w personal_phones_w personal_scooters_w personal_bicycles_w personal_televisions_w personal_mats_w)
			lab var wife_assets_tot_num "Total number of assets wife personally owns"

			* Wife's asset ownership - share of total hh assets that wife personally owns: 
			gen wife_assets_share= wife_assets_tot_num / hh_assets_tot_num
			lab var wife_assets_share "Total share of hh assets that wife personally owns"

			* 3.4.2. EMPLOYMENT
			gen business_involved_w = .
			replace business_involved_w =0 	if business_involvement_w==0 
			replace business_involved_w=1 	if business_involvement_w==1 | business_involvement_w==2
			lab var business_involved_w 	"Involved in a revenue generating activity in past 12m"
			lab val business_involved_w 		yesno

			gen business_involved_m = .
			replace business_involved_m =0 	if business_involvement_m==0 
			replace business_involved_m=1 	if business_involvement_m==1 | business_involvement_m==2
			lab var business_involved_m 	"Involved in a revenue generating activity in past 12m"
			lab val business_involved_m 		yesno

			egen bus_profit_pastmnth_w = rowtotal (profit_petty_trader_w profit_home_brewery_w profit_public_phone_w profit_food_w profit_sell_livestock_w profit_livestock_w profit_bar_w profit_miller_w profit_carpentry_w profit_blacksmith_w profit_construction_w profit_charcoal_w profit_mechanic_w profit_tailor_w profit_hairdresser_w profit_fish_seller_w profit_grocery_store_w profit_crafts_w profit_cloth_seller_w profit_agric_produce_w profit_shop_w profit_beauty_products_w profit_sell_water_w profit_meat_seller_w profit_oth_1_w profit_oth_2_w )
			egen bus_profit_pastmnth_m = rowtotal (profit_petty_trader_m profit_home_brewery_m profit_public_phone_m profit_food_m profit_sell_livestock_m profit_livestock_m profit_transport_m profit_bar_m profit_miller_m profit_carpentry_m profit_blacksmith_m profit_construction_m profit_charcoal_m profit_mechanic_m profit_tailor_m profit_hairdresser_m profit_fish_seller_m profit_grocery_store_m profit_shoe_repair_m profit_bicycle_repair_m profit_cloth_seller_m profit_agric_produce_m profit_shop_m profit_house_rent_m profit_oth_1_m profit_beauty_products_m profit_agriculture_m profit_crafts_m profit_meat_seller_m profit_oth_2_m profit_oth_3_m)		
			lab var bus_profit_pastmnth_w 	"Women- Past month profits from income generating activity"
			lab var bus_profit_pastmnth_m 	"Men - Past month profits from income generating activity"
			winsor2 bus_profit_pastmnth_w bus_profit_pastmnth_m , cuts(0 99) suffix(_win) label
				
			egen labor_market_w = rowmax(h1_apprentice_w h2_paid_wage_w h8_run_own_business_w h10_hh_agr_work_w)

			* 3.4.3. Savings
			egen savings_w = rowtotal(savings_balance_w savings_vsla_w)
				replace savings_w = . if largest_amount_w == .
			label var savings_w "Women savings"
			egen savings_m = rowtotal(savings_balance_m savings_vsla_m)
				replace savings_m = . if largest_amount_m == .
			label var savings_m "Men savings"

			foreach x of varlist savings_? h23_savings_amt_w_bl h14_savings_amount_m_bl {
				winsor2 `x' , cuts(0 99) suffix(_win) label
			}
			rename h23_savings_amt_w_bl_win savings_w_win_bl 
			rename h14_savings_amount_m_bl_win savings_m_win_bl

			gen productive_loan_w = loan_obj_start_investment_w
			replace productive_loan_w = loan_obj_incr_investment_w if productive_loan == 0 & loan_obj_incr_investment_w == 1
			
			gen productive_loan_amount_w = debt_amount_w * productive_loan_w 
			replace productive_loan_amount_w = 0 if debt_amount_w == .

			* 3.4.5. INFORMATION SHARING / CONSUMPTION OF GOODS
			* Accuracy of knowledge of spouse purchasing			
			local consumption_w bought_items_1_w bought_items_2_w bought_items_3_w bought_items_spouse_1_w bought_items_spouse_2_w bought_items_spouse_3_w good_children_education_w spouse_knw_child_ed_w spouse_bought_child_ed_w good_clothing_women_w spouse_knwldg_clothing_women_w spouse_bought_clothing_women_w good_clothing_men_w spouse_knwldg_clothing_men_w spouse_bought_clothing_men_w good_clothing_children_w spouse_knw_cloth_child_w spouse_bought_cloth_child_w
			local consumption_m bought_items_1_m bought_items_2_m bought_items_3_m bought_items_spouse_1_m bought_items_spouse_2_m bought_items_spouse_3_m good_children_education_m spouse_knwldg_child_edu_m spouse_bought_child_edu_m good_clothing_women_m spouse_knwldg_clothing_women_m spouse_bought_clothing_women_m good_clothing_men_m spouse_knwldg_clothing_men_m spouse_bought_clothing_men_m good_clothing_children_m spouse_knwldg_cloth_child_m spouse_bought_cloth_child_m 
			foreach x of varlist `consumption_w' `consumption_m'	{
				replace `x'=.d if `x'==99
			}
			
			gen 	sps_menaccur_1=	0 
			replace sps_menaccur_1= 	1 if (bought_items_1_w==1 & bought_items_spouse_1_m==1 ) | (bought_items_1_w==0 & bought_items_spouse_1_m==0 )	
			gen 	sps_womaccur_1=	0
			replace sps_womaccur_1= 	1 if  (bought_items_1_m==1 & bought_items_spouse_1_w==1 ) | (bought_items_1_m==0 & bought_items_spouse_1_w==0 )	
			gen 	sps_bothaccur_1=	0
			replace sps_bothaccur_1= 	1 if sps_menaccur_1==1 & sps_womaccur_1==1	
		
			gen 	sps_menaccur_2=	0 
			replace sps_menaccur_2= 	1 if (bought_items_2_w==1 & bought_items_spouse_2_m==1 ) | (bought_items_2_w==0 & bought_items_spouse_2_m==0 )	
			gen 	sps_womaccur_2=	0
			replace sps_womaccur_2= 	1 if  (bought_items_2_m==1 & bought_items_spouse_2_w==1 ) | (bought_items_2_m==0 & bought_items_spouse_2_w==0 )	
			gen 	sps_bothaccur_2=	0
			replace sps_bothaccur_2= 	1 if sps_menaccur_2==1 & sps_womaccur_2==1	

			gen 	sps_menaccur_3=	0 
			replace sps_menaccur_3= 	1 if (bought_items_3_w==1 & bought_items_spouse_3_m==1 ) | (bought_items_3_w==0 & bought_items_spouse_3_m==0 )	
			gen 	sps_womaccur_3=	0
			replace sps_womaccur_3= 	1 if  (bought_items_3_m==1 & bought_items_spouse_3_w==1 ) | (bought_items_3_m==0 & bought_items_spouse_3_w==0 )		
			gen 	sps_bothaccur_3=	0
			replace sps_bothaccur_3= 	1 if sps_menaccur_3==1 & sps_womaccur_3==1
			
			gen 	sps_menaccur_chldeduc=	.
			replace sps_menaccur_chldeduc=0 	if (good_children_education_w!=. & spouse_bought_child_edu_m!=.)
			replace sps_menaccur_chldeduc= 	1 if (good_children_education_w==1 & spouse_bought_child_edu_m==1 ) | (good_children_education_w==0 & spouse_bought_child_edu_m==0 )
			gen 	sps_womaccur_chldeduc=	.
			replace sps_womaccur_chldeduc=0 	if (good_children_education_m!=. & spouse_bought_child_ed_w!=.)
			replace sps_womaccur_chldeduc= 	1 if (good_children_education_m==1 & spouse_bought_child_ed_w==1 ) | (good_children_education_m==0 & spouse_bought_child_ed_w==0 )	
			gen 	sps_bothaccur_chldeduc=	0
			replace sps_bothaccur_chldeduc= 	1 if sps_womaccur_chldeduc==1 & sps_menaccur_chldeduc==1
			
			gen 	sps_menaccur_womcloth=	.
			replace sps_menaccur_womcloth=0 	if (good_clothing_women_w!=. & spouse_bought_clothing_women_m!=.)
			replace sps_menaccur_womcloth= 	1 if (good_clothing_women_w==1 & spouse_bought_clothing_women_m==1 ) | (good_clothing_women_w==0 & spouse_bought_clothing_women_m==0 )	
			gen 	sps_womaccur_mencloth=	.
			replace sps_womaccur_mencloth=0 	if (good_clothing_men_m!=. & spouse_bought_clothing_men_w!=.)
			replace sps_womaccur_mencloth= 	1 if (good_clothing_men_m==1 & spouse_bought_clothing_men_w==1 ) | (good_clothing_men_m==0 & spouse_bought_clothing_men_w==0 )	
			gen 	sps_bothaccur_owncloth=	0
			replace sps_bothaccur_owncloth= 	1 if sps_womaccur_mencloth==1 & sps_menaccur_womcloth==1	
		
			gen 	sps_menaccur_kidcloth=	.
			replace sps_menaccur_kidcloth=0 	if (good_clothing_children_w!=. & spouse_bought_cloth_child_m!=.)
			replace sps_menaccur_kidcloth= 	1 if (good_clothing_children_w==1 & spouse_bought_cloth_child_m==1 ) | (good_clothing_children_w==0 & spouse_bought_cloth_child_m==0 )
		
			gen 	sps_womaccur_kidcloth=	.
			replace sps_womaccur_kidcloth=0 	if (good_clothing_children_m!=. & spouse_bought_cloth_child_w!=.)
			replace sps_womaccur_kidcloth= 	1 if (good_clothing_children_m==1 & spouse_bought_cloth_child_w==1 ) | (good_clothing_children_m==0 & spouse_bought_cloth_child_w==0 )
		
			gen 	sps_bothaccur_kidcloth=	0
			replace sps_bothaccur_kidcloth= 	1 if sps_womaccur_kidcloth==1 & sps_menaccur_kidcloth==1

			egen sps_menaccur_nb = rowtotal(sps_menaccur*)
			label var sps_menaccur_nb "Number of accurate knowledge by husband"
			egen sps_womaccur_nb = rowtotal(sps_womaccur*)
			label var sps_womaccur_nb "Number of accurate knowledge by wife"

			* Gender-specific clothing
			gen good_clothing_women_total = .
			replace good_clothing_women_total = 0 if good_clothing_women_w != . & good_clothing_women_m != .
			replace good_clothing_women_total = 1 if good_clothing_women_w == 1 | good_clothing_women_m == 1
			
			gen good_clothing_men_total = .
			replace good_clothing_men_total = 0 if good_clothing_men_w != . & good_clothing_men_m != .
			replace good_clothing_men_total = 1 if good_clothing_men_w == 1 | good_clothing_men_m == 1

			* Other consumption
			egen bought_items_w = rowtotal(bought_items_1_w bought_items_2_w bought_items_3_w)
			egen bought_items_m = rowtotal(bought_items_1_m bought_items_2_m bought_items_3_m)

				*** 3.5. Other variables ***
				* BMI = weightkg / metres squared 
				gen ht_2a_w_met		=ht_2a_w/100
				gen ht_2a_w_squrd	=ht_2a_w_met * ht_2a_w_met 
				gen bmi_w			=(wt_2_w/ht_2a_w_squrd)

				* Legal knowledge - women
				gen 	legal_qs_correct_1=.
				replace legal_qs_correct_1=1 		if dd1_ip_rape_legal_w==0
				replace legal_qs_correct_1=0 		if dd1_ip_rape_legal_w==1 
				label 	var	legal_qs_correct_1		"Correctly believes marital rape is illegal"

				gen 	legal_qs_correct_2=.
				replace legal_qs_correct_2=1 		if dd2_parliament_woman_quota_w==1
				replace legal_qs_correct_2=0 		if dd2_parliament_woman_quota_w==0
				label 	var	legal_qs_correct_2		"Correctly believes Rwandan parliament has a gender quota"

				gen 	legal_qs_correct_3=.
				replace legal_qs_correct_3=1 		if dd4_legal_hh_head_w==3
				replace legal_qs_correct_3=0 		if dd4_legal_hh_head_w==1 | dd4_legal_hh_head_w==2
				label 	var		legal_qs_correct_3	"Correctly believes men and women are equal household head"

				gen 	legal_qs_correct_tot = legal_qs_correct_1 + legal_qs_correct_2 + legal_qs_correct_3
				label 	var		legal_qs_correct_tot		"Number of correct legal knowledge ques"


				* Know trained couple
				gen know_and_talkedtraining_w=.
				replace know_and_talkedtraining_w=0 if know_who_trained_spoke_w!=.
				replace know_and_talkedtraining_w=1 if know_who_trained_spoke_w==1 
				label var know_and_talkedtraining_w "Spillover woman knew and spoke to trained couple"

				gen know_and_talkedtraining_m=.
				replace know_and_talkedtraining_m=0 if training_knowledge_m!=.		
				replace know_and_talkedtraining_m=1 if training_knowledge_m==1 
				label var know_and_talkedtraining_m "Spillover man knew and spoke to trained couple"

				* Violence against children
				recode child_physical_abuse_w (8=0)
				gen any_kid_phys_abuse_w=.
				replace any_kid_phys_abuse_w=0 if child_physical_abuse_w==0
				replace any_kid_phys_abuse_w=1 if (child_physical_abuse_w>0 & child_physical_abuse_w<8)


					*** 3.6. Standardized weighted indices

					***** 3.6.1. Men's likelihood of violence ******
					drop YHat*
					global men_beat_likely 		"s1_disrespect_m s2_threat_leaving_m s3_cheating_m s4_flirting_m s5_spend_money_m s6_mock_m s7_control_m s8_interrupt_m s9_impt_decision_m s10_leaving_m"
					global men_likley_intimid 	"t1_intim_disresp_m t2_intim_thrtleav_m t3_intim_flirting_m t4_intim_ridicule_m t5_intim_imptdec_m"
					clonevar	beat_likly1	= s1_disrespect_m
					clonevar	beat_likly2 	= s2_threat_leaving_m
					clonevar	beat_likly3 	= s3_cheating_m
					clonevar	beat_likly4 	= s4_flirting_m
					clonevar	beat_likly5 	= s5_spend_money_m
					clonevar	beat_likly6 	= s6_mock_m
					clonevar	beat_likly7 	= s7_control_m
					clonevar	beat_likly8 	= s8_interrupt_m
					clonevar	beat_likly9 	= s9_impt_decision_m
					clonevar	beat_likly10 	= s10_leaving_m
					clonevar	beat_likly11 	= t1_intim_disresp_m
					clonevar	beat_likly12 	= t2_intim_thrtleav_m
					clonevar	beat_likly13 	= t3_intim_flirting_m
					clonevar	beat_likly14 	= t4_intim_ridicule_m
					clonevar	beat_likly15 	= t5_intim_imptdec_m

					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/15 {
						su beat_likly`count' 	if couple_type == 0
									
						local MyMean 	= r(mean)
						local MySD 		= r(sd)
									
						gen beat_likly`count'_z 	= (beat_likly`count' - `MyMean')/`MySD'
					}
							
					* Second, impute missing values at the treatment assignment group mean
					forvalues count = 1/15 {
						capture drop YHatTemp
						
						reg beat_likly`count'_z i.couple_type
						predict YHatTemp 
						
						replace beat_likly`count'_z 	= YHatTemp if beat_likly`count'_z == .
					}
						
					* Third, calculate the covariance matrix and the weights
					correl beat_likly*_z , covar
					matrix MyCovar_beat_likl 	= r(C)	
					matrix CovarInv_beat_likl   	= syminv(MyCovar_beat_likl)
					matrix MyOnes_beat_likl  	= J(rowsof(CovarInv_beat_likl), 1, 1)
					matrix MyWeights_beat_likl  	= syminv(MyOnes_beat_likl' * CovarInv_beat_likl * MyOnes_beat_likl) * (MyOnes_beat_likl' * CovarInv_beat_likl)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_beat_likl, names(weight_beat_likl)
					forvalues count = 1/4 {
						gen weighted_beat_likl_`count' 	= beat_likly`count'_z * weight_beat_likl`count'[1]
					}
					egen  	WeightedVar_beat_likl_m 	= rsum(weighted*)
					label var WeightedVar_beat_likl_m "Index: men's likelihood of becoming violent or intimidating"

					drop 	beat_likl*
					drop 	weight_beat_likl*
					drop  	weighted_beat_likl*


					****** 3.6.2. Men's beliefs about community attitudes *****	
					global beliefs_cmty_gend_m "dd2_cmty_obey_husband_m dd6_cmty_prohibit_visits_m dd7_cmty_beat_wife_m dd8_cmty_force_sex_m"
					clonevar		normsy1 = dd2_cmty_obey_husband_m	
					clonevar		normsy2=	 dd6_cmty_prohibit_visits_m
					clonevar		normsy3=	dd7_cmty_beat_wife_m
					clonevar		normsy4=	dd8_cmty_force_sex_m

					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/4 {
						su normsy`count' 	if couple_type == 0
									
						local MyMean 	= r(mean)
						local MySD 		= r(sd)
									
						gen normsy`count'_z 	= (normsy`count' - `MyMean')/`MySD'
					}
							
					* Second, impute missing values at the treatment assignment group mean
					drop YHat*

					forvalues count = 1/4 {
						capture drop YHatTemp
						
						reg normsy`count'_z i.couple_type
						predict YHatTemp 
						
						replace normsy`count'_z 	= YHatTemp if normsy`count'_z == .
					}
						
					* Third, calculate the covariance matrix and the weights
					correl normsy*_z , covar
					matrix MyCovar_norms 	= r(C)	
					matrix CovarInv_norms   	= syminv(MyCovar_norms)
					matrix MyOnes_norms  	= J(rowsof(CovarInv_norms), 1, 1)
					matrix MyWeights_norms  	= syminv(MyOnes_norms' * CovarInv_norms * MyOnes_norms) * (MyOnes_norms' * CovarInv_norms)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_norms, names(weight_norms)
					forvalues count = 1/4 {
						gen weighted_norms_`count' 	= normsy`count'_z * weight_norms`count'[1]
					}
					egen  	WeightedVar_norms_m 	= rsum(weighted*)
					label var WeightedVar_norms_m "Index: men's beliefs about conservative community norms and IPV prev"

					drop 	normsy*
					drop 	weight_norms*
					drop  	weighted_norms*

					gen uprevised_normsindx_m= WeightedVar_norms_m-WeightedVar_norms_m_bl


					****** 3.6.3. Women's beliefs about community attitudes *****
					global beliefs_cmty_gend_w "z2_cmty_obey_husband_w z6_cmty_beat_wife_w z7_cmty_force_sex_w "
					clonevar		normsy1 = z2_cmty_obey_husband_w	
					clonevar		normsy2=	 z6_cmty_beat_wife_w
					clonevar		normsy3=	z7_cmty_force_sex_w

					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/3 {
						su normsy`count' 	if couple_type == 0
									
						local MyMean 	= r(mean)
						local MySD 		= r(sd)
									
						gen normsy`count'_z 	= (normsy`count' - `MyMean')/`MySD'
					}
							
					* Second, impute missing values at the treatment assignment group mean
					drop YHat*

					forvalues count = 1/3 {
						capture drop YHatTemp
						
						reg normsy`count'_z i.couple_type
						predict YHatTemp 

						replace normsy`count'_z 	= YHatTemp if normsy`count'_z == .
					}			
						
					* Third, calculate the covariance matrix and the weights
					correl normsy*_z , covar
					matrix MyCovar_norms 	= r(C)	
					matrix CovarInv_norms   	= syminv(MyCovar_norms)
					matrix MyOnes_norms  	= J(rowsof(CovarInv_norms), 1, 1)
					matrix MyWeights_norms  	= syminv(MyOnes_norms' * CovarInv_norms * MyOnes_norms) * (MyOnes_norms' * CovarInv_norms)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_norms, names(weight_norms)
					forvalues count = 1/3 {
						gen weighted_norms_`count' 	= normsy`count'_z * weight_norms`count'[1]
					}
					egen  	WeightedVar_norms_w 	= rsum(weighted*)
					label var WeightedVar_norms_w "Index: women's beliefs about conservative community norms and IPV prev"
					drop 	normsy*
					drop 	weight_norms*
					drop  	weighted_norms*


					****** 3.6.4. Relationship quality - women *****
					clonevar	relqualy1 = 	events_laugh_w
					clonevar	relqualy2 =	 events_walk_w
					clonevar	relqualy3 =	events_leisure_w
					clonevar 	relqualy4 =	feel_respected_w_p
					clonevar 	relqualy5 =	respect_partner_w_p
					clonevar 	relqualy6 =	l3_partner_trust2_w_p
					clonevar 	relqualy7 =	marital_life_satisfied_w_p
					clonevar 	relqualy8 =	l2_emotion_sharing_w
					clonevar 	relqualy9 =	conflict_resolution_freq_w

					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/9 {
						su relqualy`count' 	if couple_type == 0						
						local MyMean 	= r(mean)
						local MySD 		= r(sd)					
						gen relqualy`count'_z 	= (relqualy`count' - `MyMean')/`MySD'
					}
							
					* Second, impute missing values at the treatment assignment group mean
					forvalues count = 1/9 {
						capture drop YHatTemp
							
						reg relqualy`count'_z i.couple_type
						predict YHatTemp
						
						replace relqualy`count'_z 	= YHatTemp if relqualy`count'_z == .
					}

					* Third, calculate the covariance matrix and the weights
					correl relqualy*_z , covar
					matrix MyCovar_relqual 	= r(C)	
					matrix CovarInv_relqual   	= syminv(MyCovar_relqual)
					matrix MyOnes_relqual  	= J(rowsof(CovarInv_relqual), 1, 1)
					matrix MyWeights_relqual 	= syminv(MyOnes_relqual' * CovarInv_relqual * MyOnes_relqual) * (MyOnes_relqual' * CovarInv_relqual)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_relqual, names(weight_relqual)
					forvalues count = 1/9 {
						gen weighted_relqual_`count' 	= relqualy`count'_z * weight_relqual`count'[1]
					}
					egen  	WeightedVar_relqual_w 	= rsum(weighted*)
					label var WeightedVar_relqual_w "Index: relationship quality - women"
					drop 	relqualy*
					drop 	weight_relqual*
					drop  	weighted_relqual*


					****** 3.6.5. Relationship quality - men *****
					clonevar	relqualy1= 	events_laugh_m
					clonevar	relqualy2=	 events_walk_m
					clonevar	relqualy3=	events_leisure_m
					clonevar 	relqualy4 =	feel_respected_m_p
					clonevar 	relqualy5 =	respect_partner_m_p
					clonevar 	relqualy6 =	l3_partner_trust2_m_p
					clonevar 	relqualy7 =	marital_life_satisfied_m_p
					clonevar 	relqualy8 =	l2_emotion_sharing_m
					clonevar 	relqualy9 =	conflict_resolution_freq_m

					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/9 {
						su relqualy`count' 	if couple_type == 0						
						local MyMean 	= r(mean)
						local MySD 		= r(sd)					
						gen relqualy`count'_z 	= (relqualy`count' - `MyMean')/`MySD'
					}
							
					* Second, impute missing values at the treatment assignment group mean
						
					forvalues count = 1/9 {
						capture drop YHatTemp
						
						reg relqualy`count'_z i.couple_type
						predict YHatTemp
						
						replace relqualy`count'_z 	= YHatTemp if relqualy`count'_z == .
					}
							
					* Third, calculate the covariance matrix and the weights
					correl relqualy*_z , covar
					matrix MyCovar_relqual 	= r(C)	
					matrix CovarInv_relqual   	= syminv(MyCovar_relqual)
					matrix MyOnes_relqual  	= J(rowsof(CovarInv_relqual), 1, 1)
					matrix MyWeights_relqual 	= syminv(MyOnes_relqual' * CovarInv_relqual * MyOnes_relqual) * (MyOnes_relqual' * CovarInv_relqual)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_relqual, names(weight_relqual)
					forvalues count = 1/9 {
						gen weighted_relqual_`count' 	= relqualy`count'_z * weight_relqual`count'[1]
					}
					egen  	WeightedVar_relqual_m 	= rsum(weighted*)
					label var WeightedVar_relqual_m "Index: relationship quality - men"
					drop 	relqualy*
					drop 	weight_relqual*
					drop  	weighted_relqual*


						
					****** 3.6.6. Depression index outcome - women *****
					* Standardizing
					global dep_w 	"cc1_pleasure_w cc2_down_w cc3_sleep_w cc4_energy_w cc5_appetite_w cc6_failure_w cc7_concentrate_w cc8_movement_dep_w cc9_hurt_self_w"
					foreach x of varlist  $dep_w {
						 local i = `i' + 1
						 clonevar dep_wy`i'= `x' 
					}

					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/9 {
						su dep_wy`count' 	if couple_type == 0						
						local MyMean 	= r(mean)
						local MySD 		= r(sd)						
						gen dep_wy`count'_z 	= (dep_wy`count' - `MyMean')/`MySD'
					}

					* Second, impute missing values at the treatment assignment group mean
					forvalues count = 1/9 {
						capture drop YHatTemp
							
						reg dep_wy`count'_z i.couple_type
						predict YHatTemp
							
						replace dep_wy`count'_z 	= YHatTemp if dep_wy`count'_z == .
					}						
									
					* Third, I calculate the covariance matrix and the weights...
					correl dep_wy*_z , covar
					matrix MyCovar_dep_w 	= r(C)	
					matrix CovarInv_dep_w   	= syminv(MyCovar_dep_w)
					matrix MyOnes_dep_w  	= J(rowsof(CovarInv_dep_w), 1, 1)
					matrix MyWeights_dep_w  	= syminv(MyOnes_dep_w' * CovarInv_dep_w * MyOnes_dep_w) * (MyOnes_dep_w' * CovarInv_dep_w)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_dep_w, names(weight_dep_w)
					forvalues count = 1/9 {
						gen weighted_dep_w_`count' 	= dep_wy`count'_z * weight_dep_w`count'[1]
					}
					egen  	WeightedVar_dep_w 	= rsum(weighted_dep_w*)
					label var WeightedVar_dep_w "Index: depression - women"
					drop 	dep_wy*
					drop 	weight_dep_w*
					drop  	weighted_dep_w*

								
					****** 3.6.7.  Depression index outcome - men *****
					global dep_m 	"cc1_pleasure_m cc2_down_m cc3_sleep_m cc4_energy_m cc5_appetite_m cc6_failure_m cc7_concentrate_m cc8_movement_dep_m cc9_hurt_self_m"		
					foreach x of varlist  $dep_m {
						local g = `g' + 1
						clonevar dep_my`g'= `x' 
					}
																						
					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/9 {
						su dep_my`count' 	if couple_type == 0
									
						local MyMean 	= r(mean)
						local MySD 		= r(sd)
									
						gen dep_my`count'_z 	= (dep_my`count' - `MyMean')/`MySD'
					}

					* Second, impute missing values at the treatment assignment group mean
					forvalues count = 1/9 {
						capture drop YHatTemp
								
						reg dep_my`count'_z i.couple_type
						predict YHatTemp
								
						replace dep_my`count'_z 	= YHatTemp if dep_my`count'_z == .
					}						
										
					* Third, calculate the covariance matrix and the weights
					correl dep_my*_z , covar
					matrix MyCovar_dep_m 	= r(C)	
					matrix CovarInv_dep_m   	= syminv(MyCovar_dep_m)
					matrix MyOnes_dep_m  	= J(rowsof(CovarInv_dep_m), 1, 1)
					matrix MyWeights_dep_m  	= syminv(MyOnes_dep_m' * CovarInv_dep_m * MyOnes_dep_m) * (MyOnes_dep_m' * CovarInv_dep_m)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_dep_m, names(weight_dep_m)
					forvalues count = 1/9 {
						gen weighted_dep_m_`count' 	= dep_my`count'_z * weight_dep_m`count'[1]
					}
					egen  	WeightedVar_dep_m 	= rsum(weighted_dep_m*)
					label var WeightedVar_dep_m "Index: depression - men"
					drop 	dep_my*
					drop 	weight_dep_m*
					drop  	weighted_dep_m*


					****** 3.6.8. Stress index outcome - women *****
					* Standardizing
					global stress_w 	"stress_nervous_w stress_confidence_w stress_irritations_w stress_anger_w"
					foreach x of varlist  $stress_w {
						 local j = `j' + 1
						 clonevar stress_wy`j'= `x' 
					}

					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/4 {
						su stress_wy`count' 	if couple_type == 0						
						local MyMean 	= r(mean)
						local MySD 		= r(sd)						
						gen stress_wy`count'_z 	= (stress_wy`count' - `MyMean')/`MySD'
					}

					* Second, impute missing values at the treatment assignment group mean
					forvalues count = 1/4 {
						capture drop YHatTemp
							
						reg stress_wy`count'_z i.couple_type
						predict YHatTemp
							
						replace stress_wy`count'_z 	= YHatTemp if stress_wy`count'_z == .
					}						
									
					* Third, I calculate the covariance matrix and the weights...
					correl stress_wy*_z , covar
					matrix MyCovar_stress_w 	= r(C)	
					matrix CovarInv_stress_w   	= syminv(MyCovar_stress_w)
					matrix MyOnes_stress_w  	= J(rowsof(CovarInv_stress_w), 1, 1)
					matrix MyWeights_stress_w  	= syminv(MyOnes_stress_w' * CovarInv_stress_w * MyOnes_stress_w) * (MyOnes_stress_w' * CovarInv_stress_w)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_stress_w, names(weight_stress_w)
					forvalues count = 1/4 {
						gen weighted_stress_w_`count' 	= stress_wy`count'_z * weight_stress_w`count'[1]
					}
					egen  	WeightedVar_stress_w 	= rsum(weighted_stress_w*)
					label var WeightedVar_stress_w "Index: stress - women"
					drop 	stress_wy*
					drop 	weight_stress_w*
					drop  	weighted_stress_w*

								
					****** 3.6.9.  Stress index outcome - men *****
					global stress_m 	"stress_nervous_m stress_confidence_m stress_irritations_m stress_anger_m"
					foreach x of varlist  $stress_m {
						local k = `k' + 1
						clonevar stress_my`k'= `x' 
					}
																						
					* First, convert to z scores using the control group (signs are already switched)
					forvalues count = 1/4 {
						su stress_my`count' 	if couple_type == 0
									
						local MyMean 	= r(mean)
						local MySD 		= r(sd)
									
						gen stress_my`count'_z 	= (stress_my`count' - `MyMean')/`MySD'
					}

					* Second, impute missing values at the treatment assignment group mean
					forvalues count = 1/4 {
						capture drop YHatTemp
								
						reg stress_my`count'_z i.couple_type
						predict YHatTemp
								
						replace stress_my`count'_z 	= YHatTemp if stress_my`count'_z == .
					}						
										
					* Third, calculate the covariance matrix and the weights
					correl stress_my*_z , covar
					matrix MyCovar_stress_m 	= r(C)	
					matrix CovarInv_stress_m   	= syminv(MyCovar_stress_m)
					matrix MyOnes_stress_m  	= J(rowsof(CovarInv_stress_m), 1, 1)
					matrix MyWeights_stress_m  	= syminv(MyOnes_stress_m' * CovarInv_stress_m * MyOnes_stress_m) * (MyOnes_stress_m' * CovarInv_stress_m)

					* Finally, create weighted variables from matrix weights
					svmat MyWeights_stress_m, names(weight_stress_m)
					forvalues count = 1/4 {
						gen weighted_stress_m_`count' 	= stress_my`count'_z * weight_stress_m`count'[1]
					}
					egen  	WeightedVar_stress_m 	= rsum(weighted_stress_m*)
					label var WeightedVar_stress_m "Index: stress - men"
					drop 	stress_my*
					drop 	weight_stress_m*
					drop  	weighted_stress_m*								




************************************************
* 4. Village leader data
************************************************

clonevar village_id= village_id_w_bl 
merge m:1 village_id using "$ROOT/Data/vleader_clean_appended_WB.dta", nogen

gen vill_pop_und200hh = 0
replace vill_pop_und200hh=1 if (c1==3 | c1==4 | c1==5 | c1==6)	
label var vill_pop_und200hh "Live in village with under 200 hhs"

* Generate variable for whether village actually lived in was a treated village
gen treated_village_code_w=village_id_w_bl if village_treatment==1
gen control_village_code_w=village_id_w_bl if village_treatment==0
gen vill_actuallylived_was_t = .
replace vill_actuallylived_was_t=0 if village_res_w_bl!= village_id_w_bl 
replace vill_actuallylived_was_t=1 if village_treatment==1 &  village_res_w_bl== village_id_w_bl 

levelsof treated_village_code_w, local(levels) 
foreach l of local levels {
	replace vill_actuallylived_was_t= 1 if village_res_w_bl== "`l'"
}
levelsof control_village_code_w, local(levels) 
foreach a of local levels {
	replace vill_actuallylived_was_t= 0 if village_res_w_bl== "`a'"
}
replace vill_actuallylived_was_t=. if village_res_w_bl==""





************************************************
* 5. Final preparation for analysis
************************************************

* Created baseline missing and ancova controls
clonevar i1_vsla_ptcp_yrs_w_bl = i1_vsla_ptcp_length_yrs_w_bl
foreach x of varlist emo_violence_dum_bl physical_violence_dum_bl sexual_violence_dum_bl ///
	own_gendernorms_w_bl own_gendernorms_m_bl own_ipv_justified_w_bl own_ipv_justified_m_bl own_refusesex_w_bl own_refusesex_m_bl reasons_lklyvio_m_eg_bl ///
	gap_gndrnrms_bl gap_ipvjust_bl ptnr_drnktoomuch_w_bl alc_excess_m_bl ///
	emo_contrl_behav_dum_bl s17_injuries_minor s17_injuries_minor_bl s23_injuries_sex_w_bl oo1_m2_signphyspain_w_bl ///
	emo_violence_m_bl physical_violence_m_bl savings_w_win_bl savings_m_win_bl ///
	public_humiliation_w_bl insult_w_bl slapped_w_bl twisted_arm_w_bl punched_w_bl beaten_w_bl ///
	strangled_w_bl attacked_wpn_w_bl forced_sex_w_bl forced_sex_fear_w_bl degrd_sex_w_bl ///
	slapped_w_sof_bl twisted_arm_w_sof_bl punched_w_sof_bl beaten_w_sof_bl strangled_w_sof_bl attacked_wpn_w_sof_bl ///
	forced_sex_w_sof_bl forced_sex_fear_w_sof_bl degrd_sex_w_sof_bl ///
	emo_vio_numb_bl phys_vio_numb_bl sex_vio_numb_bl ///
	emo_vio_ref_bl phys_vio_ref_bl sex_vio_ref_bl dep_score_m t1_ptnr_alcl_use_w_bl ///
	WeightedVar_norms_w_bl z2_cmty_obey_husband_w_bl z5_cmnty_jealousy_w_bl z6_cmty_beat_wife_w_bl z7_cmty_force_sex_w_bl ///
	WeightedVar_norms_m_bl dd2_cmty_obey_husband_m_bl dd5_cmnty_jealousy_m_bl dd7_cmty_beat_wife_m_bl dd8_cmty_force_sex_m_bl ///
	dep_total_score_m_bl become_intimidating_m_bl intent_violence_m_bl trauma_score_m_bl ///
	e29_education_m_bl_clean e11_education_w_bl_clean oo7_sdm7_tokens_give_m_bl dd1_cmty_shame_hhwrk_m_bl ///
	dd3_cmty_womcontl_m_bl dd4_cmty_noin_m_bl vmn_own_gendernorms_w_bl dd6_cmty_prohib_vist_m_bl  ///
	k6_obey_husband_m_bl k7_woman_control_man_m_bl k8_ipv_private_m_bl l1_conflict_resolution_m_bl l2_emotion_sharing_m_bl /// 
	l3_partner_trust2_m_bl h2_paid_employed_m_bl e15_concubines_m_bl e10_age_years_m_bl e9_household_size_m_bl ll1_sdm7_tokens_give_w_bl i1_vsla_ptcp_yrs_w_bl {
gen `x'mis =0
replace `x'mis=1 if `x'==.r | `x'==. | `x'==.n

gen `x'_ancv=`x'
replace `x'_ancv=0 if `x'==.r | `x'==. | `x'==.n
}

* Create interaction variables
gen inter = .
gen	int_treat = .
gen int_spill = .
label var inter "Characteristic"
label var int_treat "Treated * Characteristic"
label var int_spill "Spillover * Characteristic" 

gen	no_vio_bl_treat = no_vio_bl * couple_treat
gen no_vio_bl_spill = no_vio_bl * spillover_couple 
label var no_vio_bl "No violence at baseline"
label var no_vio_bl_treat "Treated * No violence at baseline"
label var no_vio_bl_spill "Spillover * No violence at baseline"

gen mig = migrate_work_m_bl
gen	mig_treat = migrate_work_m_bl* couple_treat
gen mig_spill = migrate_work_m_bl* spillover_couple 
label var mig "Husband worked away"
label var mig_treat "Treated * Husband worked away"
label var mig_spill "Spillover * Husband worked away"

* First difference 
gen emo_violence_fd = emo_violence_dum - emo_violence_dum_bl
gen physical_violence_fd = physical_violence_dum - physical_violence_dum_bl
gen sexual_violence_fd = sexual_violence_dum - sexual_violence_dum_bl

* Labels 
label var emo_violence_dum "Emotional IPV"
label var physical_violence_dum "Physical IPV"
label var sexual_violence_dum "Sexual IPV"


*** Save data ***
if _N == 2728 { // This creates the balance table A1 and requires to comment line 23 in this do file
	keep a12_couples_survey_w_bl strata village_id_m_num emo_violence_dum_bl physical_violence_dum_bl sexual_violence_dum_bl d8_age_years_w_bl ///
	e11_education_w_bl_clean e12_n_bio_children_w_bl own_ipv_justified_w_bl own_gendernorms_w_bl e10_age_years_m_bl e29_education_m_bl_clean ///
	own_ipv_justified_m_bl own_gendernorms_m_bl cmty_beat_wife_low_bl cmty_force_sex_low_bl civil_legal_marriage_bl g1_meals_skipped_m_bl
	
	save  "$ROOT\Data\Final\indash_community_final.dta", replace 
}
else {
	keep couple_treat spillover_couple couple_type strata village_id_m_bl village_id_m_num emo_violence_dum physical_violence_dum sexual_violence_dum ///
	WeightedVar_relqual_w WeightedVar_relqual_m WeightedVar_dep_w WeightedVar_dep_m escalate_physical_w drink_quarrel_w husb_takemoney_hhben_w spouse_cheat_w ///
	own_gendernorms_w own_ipv_justified_w own_refusesex_w own_gendernorms_m own_ipv_justified_m own_refusesex_m reasons_lklyvio_m_eg ///
	gap_gndrnrms gap_ipvjust wifegtmoreprog_ipvjust_dum ///
	wantmre_dec_idl_hhexpns_w wantmre_dec_idl_chldbr_w dec_input_inc_w_role dec_input_hh_inc_w_role dec_input_hh_exp_w_role dec_input_child_w_role ///
	wantmre_dec_idl_hhexpns_m wantmre_dec_idl_chldbr_m dec_input_inc_m_role  dec_input_hh_inc_m_role dec_input_hh_exp_m_role dec_input_child_m_role ///
	formalized_marr_m_blel civil_legal_marriage_bl ptnr_drnktoomuch_w alc_excess_m alc_excess_m_bl alcohol_daily_m_ful formalized_marr_m_blel husb_takemoney_hhben_w domestic_care_mins_w domestic_care_mins_m ///
	emo_violence_dum_bl physical_violence_dum_bl sexual_violence_dum_bl d8_age_years_w_bl e11_education_w_bl_clean e12_n_bio_children_w_bl own_ipv_justified_w_bl own_gendernorms_w_bl ///
	e10_age_years_m_bl e29_education_m_bl_clean own_ipv_justified_m_bl own_gendernorms_m_bl cmty_beat_wife_low_bl cmty_force_sex_low_bl civil_legal_marriage_bl g1_meals_skipped_m_bl ///
	emo_contrl_behav_dum s17_injuries_minor s23_injuries_sex_w oo1_m2_signphyspain_w emo_violence_m physical_violence_m knowledge_ipv_m_win knowledge_ipv_women_m_win ///
	any_kid_phys_abuse_w marital_disagreements_9_w hh_assets_tot_num wife_assets_share business_involved_w business_involved_m ///
	savings_w_win savings_m_win no_vio_bl married_pre94_narr j4_bride_price_given_m_bl married_w_bl formalized_marr_w_blel pid_w_bl knew_gendertraining_w_bl ///
	public_humiliation_w insult_w slapped_w twisted_arm_w punched_w beaten_w strangled_w attacked_wpn_w forced_sex_w forced_sex_fear_w degrd_sex_w ///
	slapped_w_sof twisted_arm_w_sof punched_w_sof beaten_w_sof strangled_w_sof attacked_wpn_w_sof forced_sex_w_sof forced_sex_fear_w_sof degrd_sex_w_sof ///
	emo_vio_numb phys_vio_numb sex_vio_numb emo_vio_ref phys_vio_ref sex_vio_ref ipv_report_2_w_cln safe_space_visit_w s24_violence_talked_w ipv_report_2_w_cln safe_space_visit_m ///
	oo1_meta1_distress_w oo5_m5_cnsl_refer_w_all oo6_m6_spk_cnsl_w migrate_work_m_bl WeightedVar_norms_w z2_cmty_obey_husband_w z5_cmnty_jealousy_w z6_cmty_beat_wife_w z7_cmty_force_sex_w ///
	WeightedVar_norms_m dd2_cmty_obey_husband_m dd5_cmnty_jealousy_m dd7_cmty_beat_wife_m dd8_cmty_force_sex_m uprevised_normsindx_m ///
	vill_pop_und200hh trauma_score_m_bl WeightedVar_dep_m_bl aa12_fth_phipv_m_bl_dm v2_alcohol_excess_dum_m_bl_ful ptnr_drnktoomuch_w_bl ///	
	WeightedVar_beat_likl_m_bl d5_partner_title1_w_bl l3_partner_trust2_m_bl m3_partner_trust2_w_bl dep_score_m dep_score_mmis dep_score_m_ancv t1_ptnr_alcl_use_w_bl t2_ptnr_drinktoomuch_w_bl ///
	v2_alcohol_excess_m_bl  gg8_rel_talks_num_m_bl gg4_rel_blood_num_m_bl own_gendernorms_w_equit_bl unable_to_work_w_bl sector_id Napplicantscat ///
	q1_beat_neglect_child_w_bl_p q2_beating_refusing_sex_w_bl_p q3_beating_disobey_w_bl_p q4_beating_burn_food_w_bl_p q5_beat_suspect_unfaith_w_bl_p ///
	own_refusesex_w_bl numb_villagerels_w_bl numb_closefriends_w_bl numb_villagerels_m_bl numb_closefriends_m_bl dep_total_score_m_bl become_intimidating_m_bl intent_violence_m_bl trauma_score_m_bl ///
	own_refusesex_m_bl oo7_sdm7_tokens_give_m_bl dd1_cmty_shame_hhwrk_m_bl dd2_cmty_obey_husband_m_bl dd3_cmty_womcontl_m_bl dd4_cmty_noin_m_bl vmn_own_gendernorms_w_bl ///
	dd5_cmnty_jealousy_m_bl dd6_cmty_prohib_vist_m_bl dd7_cmty_beat_wife_m_bl dd8_cmty_force_sex_m_bl k6_obey_husband_m_bl k7_woman_control_man_m_bl k8_ipv_private_m_bl ///
	l1_conflict_resolution_m_bl l2_emotion_sharing_m_bl l3_partner_trust2_m_bl h2_paid_employed_m_bl e15_concubines_m_bl  e9_household_size_m_bl  ll1_sdm7_tokens_give_w_bl  i1_vsla_ptcp_yrs_w_bl ///
	emo_vio_act_refeqlyes emo_vio_act_refeqlno phys_vio_refeqlyes phys_vio_refeqlno sex_vio_act_refeqlyes sex_vio_act_refeqlno ///
	emo_vio_act_refeqlyes_bl emo_vio_act_refeqlno_bl phys_vio_refeqlyes_bl phys_vio_refeqlno_bl sex_vio_act_refeqlyes_bl sex_vio_act_refeqlno_bl ///
	vill_notres within* actual_couple_treatment  village_treatment  vill_actuallylived_was_t *mis *_ancv inter int_treat int_spill no_vio_bl_treat no_vio_bl_spill ///
	mig mig_treat mig_spill emo_violence_fd physical_violence_fd sexual_violence_fd lottery ///
	productive_loan_amount_w g1_meals_skipped_m bus_profit_pastmnth_w_win h2_paid_wage_w bmi_w bus_profit_pastmnth_m_win ///
	h22_prevent_work_outside_w overall_happiness_w_p ll1_sdm7_tokens_give_w oo7_sdm7_tokens_give_m ///
	bought_items_w bought_items_m debt_amount_w labor_market_w eco_coercion_dum ///
	WeightedVar_stress_w WeightedVar_stress_m sps_menaccur_nb sps_womaccur_nb good_clothing_*_total phys_or_sex_vio
	
	save  "$ROOT\Data\Final\indash_vsla_final.dta", replace 
}
