/***********************************************************************************************************
The Unintended Impacts of an Intimate Partner Violence Prevention Program: Experimental Evidence from Rwanda
REPLICATION FILE 3 - ONLINE APPENDIX

Prepared by: Ludovic Bequet 12 December 2024
Stata version: 15.1
************************************************************************************************************/

use "$data/indash_vsla_final.dta", clear
xtset strata	


*** PAP variables ***
local pap_eco g1_meals_skipped_m bought_items_w good_clothing_women_total productive_loan_amount_w bus_profit_pastmnth_w_win h2_paid_wage_w labor_market_w bmi_w bought_items_m good_clothing_men_total bus_profit_pastmnth_m_win
local pap_other eco_coercion_dum overall_happiness_w_p WeightedVar_stress_w WeightedVar_stress_m ll1_sdm7_tokens_give_w oo7_sdm7_tokens_give_m sps_womaccur_nb sps_menaccur_nb

foreach var in `pap_eco' {
	eststo clear		
	eststo: xi: qui reg  `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
		lincom couple_treat - spillover_couple
		local	difpval1=	r(p)		
		sum `var' if couple_type==0
		local contmean1 = r(mean)
		outreg2  using "$appendix/table1a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
		adds("Treated vs Spillover p-value", `difpval1')  addtext(ANCOVA controls, NO)  ///
		  keep(couple_treat spillover_couple) nonotes
}
foreach var in `pap_other' {
	eststo clear		
	eststo: xi: qui reg  `var' couple_treat spillover_couple i.strata,  vce(cluster village_id_m_bl)  
		lincom couple_treat - spillover_couple
		local	difpval1=	r(p)		
		sum `var' if couple_type==0
		local contmean1 = r(mean)
		outreg2  using "$appendix/table1b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
		adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(ANCOVA controls, NO)  ///
		  keep(couple_treat spillover_couple) nonotes
}


*** Violence escalation
eststo clear		
		eststo: xi: qui reg phys_or_sex_vio couple_treat spillover_couple i.strata if emo_violence_dum_bl == 1 & physical_violence_dum_bl == 0 & sexual_violence_dum_bl == 0,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum phys_or_sex_vio if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$appendix/table2.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(ANCOVA controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes
eststo clear		
		eststo: xi: qui reg sexual_violence_dum couple_treat spillover_couple i.strata if physical_violence_dum_bl == 1 & sexual_violence_dum_bl == 0,  vce(cluster village_id_m_bl)  
			lincom couple_treat - spillover_couple
			local	difpval1=	r(p)		
			sum sexual_violence_dum if couple_type==0
			local contmean1 = r(mean)
			outreg2  using "$appendix/table2.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("Control mean", `contmean1', "Treated vs Spillover p-value", `difpval1')  addtext(ANCOVA controls, NO) ///
			 keep(couple_treat spillover_couple) nonotes

*** Husband migration and type and frequency of IPV
replace mig = migrate_work_m_bl
replace	mig_treat = migrate_work_m_bl* couple_treat
replace mig_spill = migrate_work_m_bl* spillover_couple 
label var mig "Husband worked away"
label var mig_treat "Treated * Husband worked away"
label var mig_spill "Spillover * Husband worked away"
	local ipv_freqa slapped_w_sof twisted_arm_w_sof punched_w_sof beaten_w_sof strangled_w_sof attacked_wpn_w_sof  	
	local ipv_freqb forced_sex_w_sof forced_sex_fear_w_sof degrd_sex_w_sof 
	local ipv_freqc emo_vio_numb phys_vio_numb sex_vio_numb

foreach var in `ipv_freqa' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple mig_treat mig_spill mig i.strata,  vce(cluster village_id_m_bl)  	
		lincom couple_treat + mig_treat
			local	pval1=	r(p)			
			lincom spillover_couple + mig_spill
			local	pval2=	r(p)		
			outreg2  using "$appendix/table3a.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("P-value (Treated + Treated * Husband worked away = 0)", `pval1',"P-value (Spillover + Spillover * Husband worked away = 0)", `pval2' ) ///
			 addtext(ANCOVA controls, YES)   keep(couple_treat spillover_couple mig*) nonotes
	}
	foreach var in `ipv_freqb' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple mig_treat mig_spill mig i.strata,  vce(cluster village_id_m_bl)  	
		lincom couple_treat + mig_treat
			local	pval1=	r(p)			
			lincom spillover_couple + mig_spill
			local	pval2=	r(p)		
			outreg2  using "$appendix/table3b.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("P-value (Treated + Treated * Husband worked away = 0)", `pval1',"P-value (Spillover + Spillover * Husband worked away = 0)", `pval2' ) ///
			 addtext(ANCOVA controls, YES)   keep(couple_treat spillover_couple mig*) nonotes
	}
	foreach var in `ipv_freqc' {
		eststo clear		
		eststo: xi: qui reg `var' `var'_blmis `var'_bl_ancv couple_treat spillover_couple mig_treat mig_spill mig i.strata,  vce(cluster village_id_m_bl)  	
		lincom couple_treat + mig_treat
			local	pval1=	r(p)			
			lincom spillover_couple + mig_spill
			local	pval2=	r(p)		
			outreg2  using "$appendix/table3c.tex" , append noquote label tex(frag) nodepvar dec(2) adec(2) nocons nor2 ///
			adds("P-value (Treated + Treated * Husband worked away = 0)", `pval1',"P-value (Spillover + Spillover * Husband worked away = 0)", `pval2' ) ///
			 addtext(ANCOVA controls, YES)   keep(couple_treat spillover_couple mig*) nonotes
	}

